#[non_exhaustive]pub struct ConditionalSplitActivityBuilder { /* private fields */ }Expand description
A builder for ConditionalSplitActivity.
Implementations
Sourceimpl ConditionalSplitActivityBuilder
impl ConditionalSplitActivityBuilder
Sourcepub fn condition(self, input: Condition) -> Self
pub fn condition(self, input: Condition) -> Self
The conditions that define the paths for the activity, and the relationship between the conditions.
Sourcepub fn set_condition(self, input: Option<Condition>) -> Self
pub fn set_condition(self, input: Option<Condition>) -> Self
The conditions that define the paths for the activity, and the relationship between the conditions.
Sourcepub fn get_condition(&self) -> &Option<Condition>
pub fn get_condition(&self) -> &Option<Condition>
The conditions that define the paths for the activity, and the relationship between the conditions.
Sourcepub fn evaluation_wait_time(self, input: WaitTime) -> Self
pub fn evaluation_wait_time(self, input: WaitTime) -> Self
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.
Sourcepub fn set_evaluation_wait_time(self, input: Option<WaitTime>) -> Self
pub fn set_evaluation_wait_time(self, input: Option<WaitTime>) -> Self
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.
Sourcepub fn get_evaluation_wait_time(&self) -> &Option<WaitTime>
pub fn get_evaluation_wait_time(&self) -> &Option<WaitTime>
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.
Sourcepub fn false_activity(self, input: impl Into<String>) -> Self
pub fn false_activity(self, input: impl Into<String>) -> Self
The unique identifier for the activity to perform if the conditions aren't met.
Sourcepub fn set_false_activity(self, input: Option<String>) -> Self
pub fn set_false_activity(self, input: Option<String>) -> Self
The unique identifier for the activity to perform if the conditions aren't met.
Sourcepub fn get_false_activity(&self) -> &Option<String>
pub fn get_false_activity(&self) -> &Option<String>
The unique identifier for the activity to perform if the conditions aren't met.
Sourcepub fn true_activity(self, input: impl Into<String>) -> Self
pub fn true_activity(self, input: impl Into<String>) -> Self
The unique identifier for the activity to perform if the conditions are met.
Sourcepub fn set_true_activity(self, input: Option<String>) -> Self
pub fn set_true_activity(self, input: Option<String>) -> Self
The unique identifier for the activity to perform if the conditions are met.
Sourcepub fn get_true_activity(&self) -> &Option<String>
pub fn get_true_activity(&self) -> &Option<String>
The unique identifier for the activity to perform if the conditions are met.
Sourcepub fn build(self) -> ConditionalSplitActivity
pub fn build(self) -> ConditionalSplitActivity
Consumes the builder and constructs a ConditionalSplitActivity.