#[non_exhaustive]pub struct CustomMessageActivityBuilder { /* private fields */ }Expand description
A builder for CustomMessageActivity.
Implementations
Sourceimpl CustomMessageActivityBuilder
impl CustomMessageActivityBuilder
Sourcepub fn delivery_uri(self, input: impl Into<String>) -> Self
pub fn delivery_uri(self, input: impl Into<String>) -> Self
The destination to send the campaign or treatment to. This value can be one of the following:
-
The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
-
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
Sourcepub fn set_delivery_uri(self, input: Option<String>) -> Self
pub fn set_delivery_uri(self, input: Option<String>) -> Self
The destination to send the campaign or treatment to. This value can be one of the following:
-
The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
-
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
Sourcepub fn get_delivery_uri(&self) -> &Option<String>
pub fn get_delivery_uri(&self) -> &Option<String>
The destination to send the campaign or treatment to. This value can be one of the following:
-
The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
-
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
Sourcepub fn endpoint_types(self, input: EndpointTypesElement) -> Self
pub fn endpoint_types(self, input: EndpointTypesElement) -> Self
Appends an item to endpoint_types.
To override the contents of this collection use set_endpoint_types.
The types of endpoints to send the custom message to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.
Sourcepub fn set_endpoint_types(
self,
input: Option<Vec<EndpointTypesElement>>,
) -> Self
pub fn set_endpoint_types( self, input: Option<Vec<EndpointTypesElement>>, ) -> Self
The types of endpoints to send the custom message to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.
Sourcepub fn get_endpoint_types(&self) -> &Option<Vec<EndpointTypesElement>>
pub fn get_endpoint_types(&self) -> &Option<Vec<EndpointTypesElement>>
The types of endpoints to send the custom message to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.
Sourcepub fn message_config(self, input: JourneyCustomMessage) -> Self
pub fn message_config(self, input: JourneyCustomMessage) -> Self
Specifies the message data included in a custom channel message that's sent to participants in a journey.
Sourcepub fn set_message_config(self, input: Option<JourneyCustomMessage>) -> Self
pub fn set_message_config(self, input: Option<JourneyCustomMessage>) -> Self
Specifies the message data included in a custom channel message that's sent to participants in a journey.
Sourcepub fn get_message_config(&self) -> &Option<JourneyCustomMessage>
pub fn get_message_config(&self) -> &Option<JourneyCustomMessage>
Specifies the message data included in a custom channel message that's sent to participants in a journey.
Sourcepub fn next_activity(self, input: impl Into<String>) -> Self
pub fn next_activity(self, input: impl Into<String>) -> Self
The unique identifier for the next activity to perform, after Amazon Pinpoint calls the AWS Lambda function or web hook.
Sourcepub fn set_next_activity(self, input: Option<String>) -> Self
pub fn set_next_activity(self, input: Option<String>) -> Self
The unique identifier for the next activity to perform, after Amazon Pinpoint calls the AWS Lambda function or web hook.
Sourcepub fn get_next_activity(&self) -> &Option<String>
pub fn get_next_activity(&self) -> &Option<String>
The unique identifier for the next activity to perform, after Amazon Pinpoint calls the AWS Lambda function or web hook.
Sourcepub fn template_name(self, input: impl Into<String>) -> Self
pub fn template_name(self, input: impl Into<String>) -> Self
The name of the custom message template to use for the message. If specified, this value must match the name of an existing message template.
Sourcepub fn set_template_name(self, input: Option<String>) -> Self
pub fn set_template_name(self, input: Option<String>) -> Self
The name of the custom message template to use for the message. If specified, this value must match the name of an existing message template.
Sourcepub fn get_template_name(&self) -> &Option<String>
pub fn get_template_name(&self) -> &Option<String>
The name of the custom message template to use for the message. If specified, this value must match the name of an existing message template.
Sourcepub fn template_version(self, input: impl Into<String>) -> Self
pub fn template_version(self, input: impl Into<String>) -> Self
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versions resource.
If you don't specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that's been most recently reviewed and approved for use, depending on your workflow. It isn't necessarily the latest version of a template.
Sourcepub fn set_template_version(self, input: Option<String>) -> Self
pub fn set_template_version(self, input: Option<String>) -> Self
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versions resource.
If you don't specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that's been most recently reviewed and approved for use, depending on your workflow. It isn't necessarily the latest version of a template.
Sourcepub fn get_template_version(&self) -> &Option<String>
pub fn get_template_version(&self) -> &Option<String>
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versions resource.
If you don't specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that's been most recently reviewed and approved for use, depending on your workflow. It isn't necessarily the latest version of a template.
Sourcepub fn build(self) -> CustomMessageActivity
pub fn build(self) -> CustomMessageActivity
Consumes the builder and constructs a CustomMessageActivity.