#[non_exhaustive]pub struct DirectMessageConfigurationBuilder { /* private fields */ }Expand description
A builder for DirectMessageConfiguration.
Implementations
Sourceimpl DirectMessageConfigurationBuilder
impl DirectMessageConfigurationBuilder
Sourcepub fn adm_message(self, input: AdmMessage) -> Self
pub fn adm_message(self, input: AdmMessage) -> Self
The default push notification message for the ADM (Amazon Device Messaging) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn set_adm_message(self, input: Option<AdmMessage>) -> Self
pub fn set_adm_message(self, input: Option<AdmMessage>) -> Self
The default push notification message for the ADM (Amazon Device Messaging) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn get_adm_message(&self) -> &Option<AdmMessage>
pub fn get_adm_message(&self) -> &Option<AdmMessage>
The default push notification message for the ADM (Amazon Device Messaging) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn apns_message(self, input: ApnsMessage) -> Self
pub fn apns_message(self, input: ApnsMessage) -> Self
The default push notification message for the APNs (Apple Push Notification service) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn set_apns_message(self, input: Option<ApnsMessage>) -> Self
pub fn set_apns_message(self, input: Option<ApnsMessage>) -> Self
The default push notification message for the APNs (Apple Push Notification service) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn get_apns_message(&self) -> &Option<ApnsMessage>
pub fn get_apns_message(&self) -> &Option<ApnsMessage>
The default push notification message for the APNs (Apple Push Notification service) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn baidu_message(self, input: BaiduMessage) -> Self
pub fn baidu_message(self, input: BaiduMessage) -> Self
The default push notification message for the Baidu (Baidu Cloud Push) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn set_baidu_message(self, input: Option<BaiduMessage>) -> Self
pub fn set_baidu_message(self, input: Option<BaiduMessage>) -> Self
The default push notification message for the Baidu (Baidu Cloud Push) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn get_baidu_message(&self) -> &Option<BaiduMessage>
pub fn get_baidu_message(&self) -> &Option<BaiduMessage>
The default push notification message for the Baidu (Baidu Cloud Push) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn default_message(self, input: DefaultMessage) -> Self
pub fn default_message(self, input: DefaultMessage) -> Self
The default message for all channels.
Sourcepub fn set_default_message(self, input: Option<DefaultMessage>) -> Self
pub fn set_default_message(self, input: Option<DefaultMessage>) -> Self
The default message for all channels.
Sourcepub fn get_default_message(&self) -> &Option<DefaultMessage>
pub fn get_default_message(&self) -> &Option<DefaultMessage>
The default message for all channels.
Sourcepub fn default_push_notification_message(
self,
input: DefaultPushNotificationMessage,
) -> Self
pub fn default_push_notification_message( self, input: DefaultPushNotificationMessage, ) -> Self
The default push notification message for all push notification channels.
Sourcepub fn set_default_push_notification_message(
self,
input: Option<DefaultPushNotificationMessage>,
) -> Self
pub fn set_default_push_notification_message( self, input: Option<DefaultPushNotificationMessage>, ) -> Self
The default push notification message for all push notification channels.
Sourcepub fn get_default_push_notification_message(
&self,
) -> &Option<DefaultPushNotificationMessage>
pub fn get_default_push_notification_message( &self, ) -> &Option<DefaultPushNotificationMessage>
The default push notification message for all push notification channels.
Sourcepub fn email_message(self, input: EmailMessage) -> Self
pub fn email_message(self, input: EmailMessage) -> Self
The default message for the email channel. This message overrides the default message (DefaultMessage).
Sourcepub fn set_email_message(self, input: Option<EmailMessage>) -> Self
pub fn set_email_message(self, input: Option<EmailMessage>) -> Self
The default message for the email channel. This message overrides the default message (DefaultMessage).
Sourcepub fn get_email_message(&self) -> &Option<EmailMessage>
pub fn get_email_message(&self) -> &Option<EmailMessage>
The default message for the email channel. This message overrides the default message (DefaultMessage).
Sourcepub fn gcm_message(self, input: GcmMessage) -> Self
pub fn gcm_message(self, input: GcmMessage) -> Self
The default push notification message for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn set_gcm_message(self, input: Option<GcmMessage>) -> Self
pub fn set_gcm_message(self, input: Option<GcmMessage>) -> Self
The default push notification message for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn get_gcm_message(&self) -> &Option<GcmMessage>
pub fn get_gcm_message(&self) -> &Option<GcmMessage>
The default push notification message for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn sms_message(self, input: SmsMessage) -> Self
pub fn sms_message(self, input: SmsMessage) -> Self
The default message for the SMS channel. This message overrides the default message (DefaultMessage).
Sourcepub fn set_sms_message(self, input: Option<SmsMessage>) -> Self
pub fn set_sms_message(self, input: Option<SmsMessage>) -> Self
The default message for the SMS channel. This message overrides the default message (DefaultMessage).
Sourcepub fn get_sms_message(&self) -> &Option<SmsMessage>
pub fn get_sms_message(&self) -> &Option<SmsMessage>
The default message for the SMS channel. This message overrides the default message (DefaultMessage).
Sourcepub fn voice_message(self, input: VoiceMessage) -> Self
pub fn voice_message(self, input: VoiceMessage) -> Self
The default message for the voice channel. This message overrides the default message (DefaultMessage).
Sourcepub fn set_voice_message(self, input: Option<VoiceMessage>) -> Self
pub fn set_voice_message(self, input: Option<VoiceMessage>) -> Self
The default message for the voice channel. This message overrides the default message (DefaultMessage).
Sourcepub fn get_voice_message(&self) -> &Option<VoiceMessage>
pub fn get_voice_message(&self) -> &Option<VoiceMessage>
The default message for the voice channel. This message overrides the default message (DefaultMessage).
Sourcepub fn build(self) -> DirectMessageConfiguration
pub fn build(self) -> DirectMessageConfiguration
Consumes the builder and constructs a DirectMessageConfiguration.