#[non_exhaustive]pub struct RandomSplitActivityBuilder { /* private fields */ }Expand description
A builder for RandomSplitActivity.
Implementations
Sourceimpl RandomSplitActivityBuilder
impl RandomSplitActivityBuilder
Sourcepub fn branches(self, input: RandomSplitEntry) -> Self
pub fn branches(self, input: RandomSplitEntry) -> Self
Appends an item to branches.
To override the contents of this collection use set_branches.
The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.
Sourcepub fn set_branches(self, input: Option<Vec<RandomSplitEntry>>) -> Self
pub fn set_branches(self, input: Option<Vec<RandomSplitEntry>>) -> Self
The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.
Sourcepub fn get_branches(&self) -> &Option<Vec<RandomSplitEntry>>
pub fn get_branches(&self) -> &Option<Vec<RandomSplitEntry>>
The paths for the activity, including the percentage of participants to enter each path and the activity to perform for each path.
Sourcepub fn build(self) -> RandomSplitActivity
pub fn build(self) -> RandomSplitActivity
Consumes the builder and constructs a RandomSplitActivity.