#[non_exhaustive]pub struct RandomSplitEntryBuilder { /* private fields */ }Expand description
A builder for RandomSplitEntry.
Implementations
Sourceimpl RandomSplitEntryBuilder
impl RandomSplitEntryBuilder
Sourcepub fn next_activity(self, input: impl Into<String>) -> Self
pub fn next_activity(self, input: impl Into<String>) -> Self
The unique identifier for the next activity to perform, after completing the activity for the path.
Sourcepub fn set_next_activity(self, input: Option<String>) -> Self
pub fn set_next_activity(self, input: Option<String>) -> Self
The unique identifier for the next activity to perform, after completing the activity for the path.
Sourcepub fn get_next_activity(&self) -> &Option<String>
pub fn get_next_activity(&self) -> &Option<String>
The unique identifier for the next activity to perform, after completing the activity for the path.
Sourcepub fn percentage(self, input: i32) -> Self
pub fn percentage(self, input: i32) -> Self
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.
Sourcepub fn set_percentage(self, input: Option<i32>) -> Self
pub fn set_percentage(self, input: Option<i32>) -> Self
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.
Sourcepub fn get_percentage(&self) -> &Option<i32>
pub fn get_percentage(&self) -> &Option<i32>
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.
Sourcepub fn build(self) -> RandomSplitEntry
pub fn build(self) -> RandomSplitEntry
Consumes the builder and constructs a RandomSplitEntry.