#[non_exhaustive]pub struct SendUsersMessageRequestBuilder { /* private fields */ }Expand description
A builder for SendUsersMessageRequest.
Implementations
Sourceimpl SendUsersMessageRequestBuilder
impl SendUsersMessageRequestBuilder
Sourcepub fn context(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn context(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to context.
To override the contents of this collection use set_context.
A map of custom attribute-value pairs. For a push notification, Amazon Pinpoint adds these attributes to the data.pinpoint object in the body of the notification payload. Amazon Pinpoint also provides these attributes in the events that it generates for users-messages deliveries.
Sourcepub fn set_context(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_context(self, input: Option<HashMap<String, String>>) -> Self
A map of custom attribute-value pairs. For a push notification, Amazon Pinpoint adds these attributes to the data.pinpoint object in the body of the notification payload. Amazon Pinpoint also provides these attributes in the events that it generates for users-messages deliveries.
Sourcepub fn get_context(&self) -> &Option<HashMap<String, String>>
pub fn get_context(&self) -> &Option<HashMap<String, String>>
A map of custom attribute-value pairs. For a push notification, Amazon Pinpoint adds these attributes to the data.pinpoint object in the body of the notification payload. Amazon Pinpoint also provides these attributes in the events that it generates for users-messages deliveries.
Sourcepub fn message_configuration(self, input: DirectMessageConfiguration) -> Self
pub fn message_configuration(self, input: DirectMessageConfiguration) -> Self
The settings and content for the default message and any default messages that you defined for specific channels.
This field is required.Sourcepub fn set_message_configuration(
self,
input: Option<DirectMessageConfiguration>,
) -> Self
pub fn set_message_configuration( self, input: Option<DirectMessageConfiguration>, ) -> Self
The settings and content for the default message and any default messages that you defined for specific channels.
Sourcepub fn get_message_configuration(&self) -> &Option<DirectMessageConfiguration>
pub fn get_message_configuration(&self) -> &Option<DirectMessageConfiguration>
The settings and content for the default message and any default messages that you defined for specific channels.
Sourcepub fn template_configuration(self, input: TemplateConfiguration) -> Self
pub fn template_configuration(self, input: TemplateConfiguration) -> Self
The message template to use for the message.
Sourcepub fn set_template_configuration(
self,
input: Option<TemplateConfiguration>,
) -> Self
pub fn set_template_configuration( self, input: Option<TemplateConfiguration>, ) -> Self
The message template to use for the message.
Sourcepub fn get_template_configuration(&self) -> &Option<TemplateConfiguration>
pub fn get_template_configuration(&self) -> &Option<TemplateConfiguration>
The message template to use for the message.
Sourcepub fn trace_id(self, input: impl Into<String>) -> Self
pub fn trace_id(self, input: impl Into<String>) -> Self
The unique identifier for tracing the message. This identifier is visible to message recipients.
Sourcepub fn set_trace_id(self, input: Option<String>) -> Self
pub fn set_trace_id(self, input: Option<String>) -> Self
The unique identifier for tracing the message. This identifier is visible to message recipients.
Sourcepub fn get_trace_id(&self) -> &Option<String>
pub fn get_trace_id(&self) -> &Option<String>
The unique identifier for tracing the message. This identifier is visible to message recipients.
Sourcepub fn users(self, k: impl Into<String>, v: EndpointSendConfiguration) -> Self
pub fn users(self, k: impl Into<String>, v: EndpointSendConfiguration) -> Self
Adds a key-value pair to users.
To override the contents of this collection use set_users.
A map that associates user IDs with EndpointSendConfiguration objects. You can use an EndpointSendConfiguration object to tailor the message for a user by specifying settings such as content overrides and message variables.
Sourcepub fn set_users(
self,
input: Option<HashMap<String, EndpointSendConfiguration>>,
) -> Self
pub fn set_users( self, input: Option<HashMap<String, EndpointSendConfiguration>>, ) -> Self
A map that associates user IDs with EndpointSendConfiguration objects. You can use an EndpointSendConfiguration object to tailor the message for a user by specifying settings such as content overrides and message variables.
Sourcepub fn get_users(&self) -> &Option<HashMap<String, EndpointSendConfiguration>>
pub fn get_users(&self) -> &Option<HashMap<String, EndpointSendConfiguration>>
A map that associates user IDs with EndpointSendConfiguration objects. You can use an EndpointSendConfiguration object to tailor the message for a user by specifying settings such as content overrides and message variables.
Sourcepub fn build(self) -> SendUsersMessageRequest
pub fn build(self) -> SendUsersMessageRequest
Consumes the builder and constructs a SendUsersMessageRequest.