#[non_exhaustive]pub struct AddressConfiguration {
pub body_override: Option<String>,
pub channel_type: Option<ChannelType>,
pub context: Option<HashMap<String, String>>,
pub raw_content: Option<String>,
pub substitutions: Option<HashMap<String, Vec<String>>>,
pub title_override: Option<String>,
}Expand description
Specifies address-based configuration settings for a message that's sent directly to an endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.body_override: Option<String>The message body to use instead of the default message body. This value overrides the default message body.
channel_type: Option<ChannelType>The channel to use when sending the message.
context: Option<HashMap<String, String>>An object that maps custom attributes to attributes for the address and is attached to the message. Attribute names are case sensitive.
For a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.
raw_content: Option<String>The raw, JSON-formatted string to use as the payload for the message. If specified, this value overrides all other values for the message.
substitutions: Option<HashMap<String, Vec<String>>>A map of the message variables to merge with the variables specified by properties of the DefaultMessage object. The variables specified in this map take precedence over all other variables.
title_override: Option<String>The message title to use instead of the default message title. This value overrides the default message title.
Implementations
Sourceimpl AddressConfiguration
impl AddressConfiguration
Sourcepub fn body_override(&self) -> Option<&str>
pub fn body_override(&self) -> Option<&str>
The message body to use instead of the default message body. This value overrides the default message body.
Sourcepub fn channel_type(&self) -> Option<&ChannelType>
pub fn channel_type(&self) -> Option<&ChannelType>
The channel to use when sending the message.
Sourcepub fn context(&self) -> Option<&HashMap<String, String>>
pub fn context(&self) -> Option<&HashMap<String, String>>
An object that maps custom attributes to attributes for the address and is attached to the message. Attribute names are case sensitive.
For a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.
Sourcepub fn raw_content(&self) -> Option<&str>
pub fn raw_content(&self) -> Option<&str>
The raw, JSON-formatted string to use as the payload for the message. If specified, this value overrides all other values for the message.
Sourcepub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>
pub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>
A map of the message variables to merge with the variables specified by properties of the DefaultMessage object. The variables specified in this map take precedence over all other variables.
Sourcepub fn title_override(&self) -> Option<&str>
pub fn title_override(&self) -> Option<&str>
The message title to use instead of the default message title. This value overrides the default message title.
Sourceimpl AddressConfiguration
impl AddressConfiguration
Sourcepub fn builder() -> AddressConfigurationBuilder
pub fn builder() -> AddressConfigurationBuilder
Creates a new builder-style object to manufacture AddressConfiguration.