ApnsMessage

Struct ApnsMessage 

#[non_exhaustive]
pub struct ApnsMessage {
Show 18 fields pub apns_push_type: Option<String>, pub action: Option<Action>, pub badge: Option<i32>, pub body: Option<String>, pub category: Option<String>, pub collapse_id: Option<String>, pub data: Option<HashMap<String, String>>, pub media_url: Option<String>, pub preferred_authentication_method: Option<String>, pub priority: Option<String>, pub raw_content: Option<String>, pub silent_push: Option<bool>, pub sound: Option<String>, pub substitutions: Option<HashMap<String, Vec<String>>>, pub thread_id: Option<String>, pub time_to_live: Option<i32>, pub title: Option<String>, pub url: Option<String>,
}
Specifies the settings for a one-time message that's sent directly to an endpoint through the APNs (Apple Push Notification service) channel.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
apns_push_type: Option<String>

The type of push notification to send. Valid values are:

  • alert - For a standard notification that's displayed on recipients' devices and prompts a recipient to interact with the notification.

  • background - For a silent notification that delivers content in the background and isn't displayed on recipients' devices.

  • complication - For a notification that contains update information for an app’s complication timeline.

  • fileprovider - For a notification that signals changes to a File Provider extension.

  • mdm - For a notification that tells managed devices to contact the MDM server.

  • voip - For a notification that provides information about an incoming VoIP call.

Amazon Pinpoint specifies this value in the apns-push-type request header when it sends the notification message to APNs. If you don't specify a value for this property, Amazon Pinpoint sets the value to alert or background automatically, based on the value that you specify for the SilentPush or RawContent property of the message.

For more information about the apns-push-type request header, see Sending Notification Requests to APNs on the Apple Developer website.

action: Option<Action>

The action to occur if the recipient taps the push notification. Valid values are:

  • OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.

  • DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS platform.

  • URL - The default mobile browser on the recipient's device opens and loads the web page at a URL that you specify.

badge: Option<i32>

The key that indicates whether and how to modify the badge of your app's icon when the recipient receives the push notification. If this key isn't included in the dictionary, the badge doesn't change. To remove the badge, set this value to 0.

body: Option<String>

The body of the notification message.

category: Option<String>

The key that indicates the notification type for the push notification. This key is a value that's defined by the identifier property of one of your app's registered categories.

collapse_id: Option<String>

An arbitrary identifier that, if assigned to multiple messages, APNs uses to coalesce the messages into a single push notification instead of delivering each message individually. This value can't exceed 64 bytes.

Amazon Pinpoint specifies this value in the apns-collapse-id request header when it sends the notification message to APNs.

data: Option<HashMap<String, String>>

The JSON payload to use for a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.

media_url: Option<String>

The URL of an image or video to display in the push notification.

preferred_authentication_method: Option<String>

The authentication method that you want Amazon Pinpoint to use when authenticating with APNs, CERTIFICATE or TOKEN.

priority: Option<String>

para>5 - Low priority, the notification might be delayed, delivered as part of a group, or throttled.

/listitem>
  • 10 - High priority, the notification is sent immediately. This is the default value. A high priority notification should trigger an alert, play a sound, or badge your app's icon on the recipient's device.

  • /para>

    Amazon Pinpoint specifies this value in the apns-priority request header when it sends the notification message to APNs.

    The equivalent values for Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), are normal, for 5, and high, for 10. If you specify an FCM value for this property, Amazon Pinpoint accepts and converts the value to the corresponding APNs value.

    raw_content: Option<String>

    The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

    If you specify the raw content of an APNs push notification, the message payload has to include the content-available key. The value of the content-available key has to be an integer, and can only be 0 or 1. If you're sending a standard notification, set the value of content-available to 0. If you're sending a silent (background) notification, set the value of content-available to 1. Additionally, silent notification payloads can't include the alert, badge, or sound keys. For more information, see Generating a Remote Notification and Pushing Background Updates to Your App on the Apple Developer website.

    silent_push: Option<bool>

    Specifies whether the notification is a silent push notification. A silent (or background) push notification isn't displayed on recipients' devices. You can use silent push notifications to make small updates to your app, or to display messages in an in-app message center.

    Amazon Pinpoint uses this property to determine the correct value for the apns-push-type request header when it sends the notification message to APNs. If you specify a value of true for this property, Amazon Pinpoint sets the value for the apns-push-type header field to background.

    If you specify the raw content of an APNs push notification, the message payload has to include the content-available key. For silent (background) notifications, set the value of content-available to 1. Additionally, the message payload for a silent notification can't include the alert, badge, or sound keys. For more information, see Generating a Remote Notification and Pushing Background Updates to Your App on the Apple Developer website.

    Apple has indicated that they will throttle "excessive" background notifications based on current traffic volumes. To prevent your notifications being throttled, Apple recommends that you send no more than 3 silent push notifications to each recipient per hour.

    sound: Option<String>

    The key for the sound to play when the recipient receives the push notification. The value for this key is the name of a sound file in your app's main bundle or the Library/Sounds folder in your app's data container. If the sound file can't be found or you specify default for the value, the system plays the default alert sound.

    substitutions: Option<HashMap<String, Vec<String>>>

    The default message variables to use in the notification message. You can override these default variables with individual address variables.

    thread_id: Option<String>

    The key that represents your app-specific identifier for grouping notifications. If you provide a Notification Content app extension, you can use this value to group your notifications together.

    time_to_live: Option<i32>

    The amount of time, in seconds, that APNs should store and attempt to deliver the push notification, if the service is unable to deliver the notification the first time. If this value is 0, APNs treats the notification as if it expires immediately and the service doesn't store or try to deliver the notification again.

    Amazon Pinpoint specifies this value in the apns-expiration request header when it sends the notification message to APNs.

    title: Option<String>

    The title to display above the notification message on the recipient's device.

    url: Option<String>

    The URL to open in the recipient's default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.

    Implementations

    Source

    impl ApnsMessage

    Source

    pub fn apns_push_type(&self) -> Option<&str>

    The type of push notification to send. Valid values are:

    • alert - For a standard notification that's displayed on recipients' devices and prompts a recipient to interact with the notification.

    • background - For a silent notification that delivers content in the background and isn't displayed on recipients' devices.

    • complication - For a notification that contains update information for an app’s complication timeline.

    • fileprovider - For a notification that signals changes to a File Provider extension.

    • mdm - For a notification that tells managed devices to contact the MDM server.

    • voip - For a notification that provides information about an incoming VoIP call.

    Amazon Pinpoint specifies this value in the apns-push-type request header when it sends the notification message to APNs. If you don't specify a value for this property, Amazon Pinpoint sets the value to alert or background automatically, based on the value that you specify for the SilentPush or RawContent property of the message.

    For more information about the apns-push-type request header, see Sending Notification Requests to APNs on the Apple Developer website.

    Source

    pub fn action(&self) -> Option<&Action>

    The action to occur if the recipient taps the push notification. Valid values are:

    • OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.

    • DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS platform.

    • URL - The default mobile browser on the recipient's device opens and loads the web page at a URL that you specify.

    Source

    pub fn badge(&self) -> Option<i32>

    The key that indicates whether and how to modify the badge of your app's icon when the recipient receives the push notification. If this key isn't included in the dictionary, the badge doesn't change. To remove the badge, set this value to 0.

    Source

    pub fn body(&self) -> Option<&str>

    The body of the notification message.

    Source

    pub fn category(&self) -> Option<&str>

    The key that indicates the notification type for the push notification. This key is a value that's defined by the identifier property of one of your app's registered categories.

    Source

    pub fn collapse_id(&self) -> Option<&str>

    An arbitrary identifier that, if assigned to multiple messages, APNs uses to coalesce the messages into a single push notification instead of delivering each message individually. This value can't exceed 64 bytes.

    Amazon Pinpoint specifies this value in the apns-collapse-id request header when it sends the notification message to APNs.

    Source

    pub fn data(&self) -> Option<&HashMap<String, String>>

    The JSON payload to use for a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.

    Source

    pub fn media_url(&self) -> Option<&str>

    The URL of an image or video to display in the push notification.

    Source

    pub fn preferred_authentication_method(&self) -> Option<&str>

    The authentication method that you want Amazon Pinpoint to use when authenticating with APNs, CERTIFICATE or TOKEN.

    Source

    pub fn priority(&self) -> Option<&str>

    para>5 - Low priority, the notification might be delayed, delivered as part of a group, or throttled.

    /listitem>
  • 10 - High priority, the notification is sent immediately. This is the default value. A high priority notification should trigger an alert, play a sound, or badge your app's icon on the recipient's device.

  • /para>

    Amazon Pinpoint specifies this value in the apns-priority request header when it sends the notification message to APNs.

    The equivalent values for Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), are normal, for 5, and high, for 10. If you specify an FCM value for this property, Amazon Pinpoint accepts and converts the value to the corresponding APNs value.

    Source

    pub fn raw_content(&self) -> Option<&str>

    The raw, JSON-formatted string to use as the payload for the notification message. If specified, this value overrides all other content for the message.

    If you specify the raw content of an APNs push notification, the message payload has to include the content-available key. The value of the content-available key has to be an integer, and can only be 0 or 1. If you're sending a standard notification, set the value of content-available to 0. If you're sending a silent (background) notification, set the value of content-available to 1. Additionally, silent notification payloads can't include the alert, badge, or sound keys. For more information, see Generating a Remote Notification and Pushing Background Updates to Your App on the Apple Developer website.

    Source

    pub fn silent_push(&self) -> Option<bool>

    Specifies whether the notification is a silent push notification. A silent (or background) push notification isn't displayed on recipients' devices. You can use silent push notifications to make small updates to your app, or to display messages in an in-app message center.

    Amazon Pinpoint uses this property to determine the correct value for the apns-push-type request header when it sends the notification message to APNs. If you specify a value of true for this property, Amazon Pinpoint sets the value for the apns-push-type header field to background.

    If you specify the raw content of an APNs push notification, the message payload has to include the content-available key. For silent (background) notifications, set the value of content-available to 1. Additionally, the message payload for a silent notification can't include the alert, badge, or sound keys. For more information, see Generating a Remote Notification and Pushing Background Updates to Your App on the Apple Developer website.

    Apple has indicated that they will throttle "excessive" background notifications based on current traffic volumes. To prevent your notifications being throttled, Apple recommends that you send no more than 3 silent push notifications to each recipient per hour.

    Source

    pub fn sound(&self) -> Option<&str>

    The key for the sound to play when the recipient receives the push notification. The value for this key is the name of a sound file in your app's main bundle or the Library/Sounds folder in your app's data container. If the sound file can't be found or you specify default for the value, the system plays the default alert sound.

    Source

    pub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>

    The default message variables to use in the notification message. You can override these default variables with individual address variables.

    Source

    pub fn thread_id(&self) -> Option<&str>

    The key that represents your app-specific identifier for grouping notifications. If you provide a Notification Content app extension, you can use this value to group your notifications together.

    Source

    pub fn time_to_live(&self) -> Option<i32>

    The amount of time, in seconds, that APNs should store and attempt to deliver the push notification, if the service is unable to deliver the notification the first time. If this value is 0, APNs treats the notification as if it expires immediately and the service doesn't store or try to deliver the notification again.

    Amazon Pinpoint specifies this value in the apns-expiration request header when it sends the notification message to APNs.

    Source

    pub fn title(&self) -> Option<&str>

    The title to display above the notification message on the recipient's device.

    Source

    pub fn url(&self) -> Option<&str>

    The URL to open in the recipient's default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.

    Source

    impl ApnsMessage

    Source

    pub fn builder() -> ApnsMessageBuilder

    Creates a new builder-style object to manufacture ApnsMessage.

    Trait Implementations

    Source

    impl Clone for ApnsMessage

    Source

    fn clone(&self) -> ApnsMessage

    Returns a duplicate of the value. Read more
    1.0.0 (const: unstable) · Source

    fn clone_from(&mut self, source: &Self)

    Performs copy-assignment from source. Read more
    Source

    impl Debug for ApnsMessage

    Source

    fn fmt(&self, f: &mut Formatter<'_>) -> Result

    Formats the value using the given formatter. Read more
    Source

    impl PartialEq for ApnsMessage

    Source

    fn eq(&self, other: &ApnsMessage) -> bool

    Tests for self and other values to be equal, and is used by ==.
    1.0.0 (const: unstable) · Source

    fn ne(&self, other: &Rhs) -> bool

    Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.
    Source

    impl StructuralPartialEq for ApnsMessage

    Auto Trait Implementations

    Blanket Implementations

    Source

    impl<T> Any for T
    where T: 'static + ?Sized,

    Source

    fn type_id(&self) -> TypeId

    Gets the TypeId of self. Read more
    Source

    impl<T> Borrow<T> for T
    where T: ?Sized,

    Source

    fn borrow(&self) -> &T

    Immutably borrows from an owned value. Read more
    Source

    impl<T> BorrowMut<T> for T
    where T: ?Sized,

    Source

    fn borrow_mut(&mut self) -> &mut T

    Mutably borrows from an owned value. Read more
    Source

    impl<ST, DT> CastableFrom<ST, Initialized, Initialized> for DT
    where ST: ?Sized, DT: ?Sized,

    Source

    impl<ST, DT> CastableFrom<ST, Uninit, Uninit> for DT
    where ST: ?Sized, DT: ?Sized,

    Source

    impl<T> CloneToUninit for T
    where T: Clone,

    Source

    unsafe fn clone_to_uninit(&self, dest: *mut u8)

    🔬This is a nightly-only experimental API. (clone_to_uninit)
    Performs copy-assignment from self to dest. Read more
    Source

    impl<T> From<T> for T

    Source

    fn from(t: T) -> T

    Returns the argument unchanged.

    Source

    impl<T> Instrument for T

    Source

    fn instrument(self, span: Span) -> Instrumented<Self>

    Instruments this type with the provided Span, returning an Instrumented wrapper. Read more
    Source

    fn in_current_span(self) -> Instrumented<Self>

    Instruments this type with the current Span, returning an Instrumented wrapper. Read more
    Source

    impl<T, U> Into<U> for T
    where U: From<T>,

    Source

    fn into(self) -> U

    Calls U::from(self).

    That is, this conversion is whatever the implementation of From<T> for U chooses to do.

    Source

    impl<T> IntoEither for T

    Source

    fn into_either(self, into_left: bool) -> Either<Self, Self>

    Converts self into a Left variant of Either<Self, Self> if into_left is true. Converts self into a Right variant of Either<Self, Self> otherwise. Read more
    Source

    fn into_either_with<F>(self, into_left: F) -> Either<Self, Self>
    where F: FnOnce(&Self) -> bool,

    Converts self into a Left variant of Either<Self, Self> if into_left(&self) returns true. Converts self into a Right variant of Either<Self, Self> otherwise. Read more
    Source

    impl<Unshared, Shared> IntoShared<Shared> for Unshared
    where Shared: FromUnshared<Unshared>,

    Source

    fn into_shared(self) -> Shared

    Creates a shared type from an unshared type.
    Source

    impl<T> Paint for T
    where T: ?Sized,

    Source

    fn fg(&self, value: Color) -> Painted<&T>

    Returns a styled value derived from self with the foreground set to value.

    This method should be used rarely. Instead, prefer to use color-specific builder methods like red() and green(), which have the same functionality but are pithier.

    Example

    Set foreground color to white using fg():

    use yansi::{Paint, Color};
    
    painted.fg(Color::White);

    Set foreground color to white using white().

    use yansi::Paint;
    
    painted.white();
    Source

    fn primary(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: Primary].

    Example
    println!("{}", value.primary());
    Source

    fn fixed(&self, color: u8) -> Painted<&T>

    Returns self with the fg() set to [Color :: Fixed].

    Example
    println!("{}", value.fixed(color));
    Source

    fn rgb(&self, r: u8, g: u8, b: u8) -> Painted<&T>

    Returns self with the fg() set to [Color :: Rgb].

    Example
    println!("{}", value.rgb(r, g, b));
    Source

    fn black(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: Black].

    Example
    println!("{}", value.black());
    Source

    fn red(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: Red].

    Example
    println!("{}", value.red());
    Source

    fn green(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: Green].

    Example
    println!("{}", value.green());
    Source

    fn yellow(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: Yellow].

    Example
    println!("{}", value.yellow());
    Source

    fn blue(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: Blue].

    Example
    println!("{}", value.blue());
    Source

    fn magenta(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: Magenta].

    Example
    println!("{}", value.magenta());
    Source

    fn cyan(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: Cyan].

    Example
    println!("{}", value.cyan());
    Source

    fn white(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: White].

    Example
    println!("{}", value.white());
    Source

    fn bright_black(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: BrightBlack].

    Example
    println!("{}", value.bright_black());
    Source

    fn bright_red(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: BrightRed].

    Example
    println!("{}", value.bright_red());
    Source

    fn bright_green(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: BrightGreen].

    Example
    println!("{}", value.bright_green());
    Source

    fn bright_yellow(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: BrightYellow].

    Example
    println!("{}", value.bright_yellow());
    Source

    fn bright_blue(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: BrightBlue].

    Example
    println!("{}", value.bright_blue());
    Source

    fn bright_magenta(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: BrightMagenta].

    Example
    println!("{}", value.bright_magenta());
    Source

    fn bright_cyan(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: BrightCyan].

    Example
    println!("{}", value.bright_cyan());
    Source

    fn bright_white(&self) -> Painted<&T>

    Returns self with the fg() set to [Color :: BrightWhite].

    Example
    println!("{}", value.bright_white());
    Source

    fn bg(&self, value: Color) -> Painted<&T>

    Returns a styled value derived from self with the background set to value.

    This method should be used rarely. Instead, prefer to use color-specific builder methods like on_red() and on_green(), which have the same functionality but are pithier.

    Example

    Set background color to red using fg():

    use yansi::{Paint, Color};
    
    painted.bg(Color::Red);

    Set background color to red using on_red().

    use yansi::Paint;
    
    painted.on_red();
    Source

    fn on_primary(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: Primary].

    Example
    println!("{}", value.on_primary());
    Source

    fn on_fixed(&self, color: u8) -> Painted<&T>

    Returns self with the bg() set to [Color :: Fixed].

    Example
    println!("{}", value.on_fixed(color));
    Source

    fn on_rgb(&self, r: u8, g: u8, b: u8) -> Painted<&T>

    Returns self with the bg() set to [Color :: Rgb].

    Example
    println!("{}", value.on_rgb(r, g, b));
    Source

    fn on_black(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: Black].

    Example
    println!("{}", value.on_black());
    Source

    fn on_red(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: Red].

    Example
    println!("{}", value.on_red());
    Source

    fn on_green(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: Green].

    Example
    println!("{}", value.on_green());
    Source

    fn on_yellow(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: Yellow].

    Example
    println!("{}", value.on_yellow());
    Source

    fn on_blue(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: Blue].

    Example
    println!("{}", value.on_blue());
    Source

    fn on_magenta(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: Magenta].

    Example
    println!("{}", value.on_magenta());
    Source

    fn on_cyan(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: Cyan].

    Example
    println!("{}", value.on_cyan());
    Source

    fn on_white(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: White].

    Example
    println!("{}", value.on_white());
    Source

    fn on_bright_black(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: BrightBlack].

    Example
    println!("{}", value.on_bright_black());
    Source

    fn on_bright_red(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: BrightRed].

    Example
    println!("{}", value.on_bright_red());
    Source

    fn on_bright_green(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: BrightGreen].

    Example
    println!("{}", value.on_bright_green());
    Source

    fn on_bright_yellow(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: BrightYellow].

    Example
    println!("{}", value.on_bright_yellow());
    Source

    fn on_bright_blue(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: BrightBlue].

    Example
    println!("{}", value.on_bright_blue());
    Source

    fn on_bright_magenta(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: BrightMagenta].

    Example
    println!("{}", value.on_bright_magenta());
    Source

    fn on_bright_cyan(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: BrightCyan].

    Example
    println!("{}", value.on_bright_cyan());
    Source

    fn on_bright_white(&self) -> Painted<&T>

    Returns self with the bg() set to [Color :: BrightWhite].

    Example
    println!("{}", value.on_bright_white());
    Source

    fn attr(&self, value: Attribute) -> Painted<&T>

    Enables the styling Attribute value.

    This method should be used rarely. Instead, prefer to use attribute-specific builder methods like bold() and underline(), which have the same functionality but are pithier.

    Example

    Make text bold using attr():

    use yansi::{Paint, Attribute};
    
    painted.attr(Attribute::Bold);

    Make text bold using using bold().

    use yansi::Paint;
    
    painted.bold();
    Source

    fn bold(&self) -> Painted<&T>

    Returns self with the attr() set to [Attribute :: Bold].

    Example
    println!("{}", value.bold());
    Source

    fn dim(&self) -> Painted<&T>

    Returns self with the attr() set to [Attribute :: Dim].

    Example
    println!("{}", value.dim());
    Source

    fn italic(&self) -> Painted<&T>

    Returns self with the attr() set to [Attribute :: Italic].

    Example
    println!("{}", value.italic());
    Source

    fn underline(&self) -> Painted<&T>

    Returns self with the attr() set to [Attribute :: Underline].

    Example
    println!("{}", value.underline());

    Returns self with the attr() set to [Attribute :: Blink].

    Example
    println!("{}", value.blink());

    Returns self with the attr() set to [Attribute :: RapidBlink].

    Example
    println!("{}", value.rapid_blink());
    Source

    fn invert(&self) -> Painted<&T>

    Returns self with the attr() set to [Attribute :: Invert].

    Example
    println!("{}", value.invert());
    Source

    fn conceal(&self) -> Painted<&T>

    Returns self with the attr() set to [Attribute :: Conceal].

    Example
    println!("{}", value.conceal());
    Source

    fn strike(&self) -> Painted<&T>

    Returns self with the attr() set to [Attribute :: Strike].

    Example
    println!("{}", value.strike());
    Source

    fn quirk(&self, value: Quirk) -> Painted<&T>

    Enables the yansi Quirk value.

    This method should be used rarely. Instead, prefer to use quirk-specific builder methods like mask() and wrap(), which have the same functionality but are pithier.

    Example

    Enable wrapping using .quirk():

    use yansi::{Paint, Quirk};
    
    painted.quirk(Quirk::Wrap);

    Enable wrapping using wrap().

    use yansi::Paint;
    
    painted.wrap();
    Source

    fn mask(&self) -> Painted<&T>

    Returns self with the quirk() set to [Quirk :: Mask].

    Example
    println!("{}", value.mask());
    Source

    fn wrap(&self) -> Painted<&T>

    Returns self with the quirk() set to [Quirk :: Wrap].

    Example
    println!("{}", value.wrap());
    Source

    fn linger(&self) -> Painted<&T>

    Returns self with the quirk() set to [Quirk :: Linger].

    Example
    println!("{}", value.linger());
    Source

    fn clear(&self) -> Painted<&T>

    👎Deprecated since 1.0.1:

    renamed to resetting() due to conflicts with Vec::clear(). The clear() method will be removed in a future release.

    Returns self with the quirk() set to [Quirk :: Clear].

    Example
    println!("{}", value.clear());
    Source

    fn resetting(&self) -> Painted<&T>

    Returns self with the quirk() set to [Quirk :: Resetting].

    Example
    println!("{}", value.resetting());
    Source

    fn bright(&self) -> Painted<&T>

    Returns self with the quirk() set to [Quirk :: Bright].

    Example
    println!("{}", value.bright());
    Source

    fn on_bright(&self) -> Painted<&T>

    Returns self with the quirk() set to [Quirk :: OnBright].

    Example
    println!("{}", value.on_bright());
    Source

    fn whenever(&self, value: Condition) -> Painted<&T>

    Conditionally enable styling based on whether the Condition value applies. Replaces any previous condition.

    See the crate level docs for more details.

    Example

    Enable styling painted only when both stdout and stderr are TTYs:

    use yansi::{Paint, Condition};
    
    painted.red().on_yellow().whenever(Condition::STDOUTERR_ARE_TTY);
    Source

    fn new(self) -> Painted<Self>
    where Self: Sized,

    Create a new Painted with a default Style. Read more
    Source

    fn paint<S>(&self, style: S) -> Painted<&Self>
    where S: Into<Style>,

    Apply a style wholesale to self. Any previous style is replaced. Read more
    Source

    impl<T> Read<Exclusive, BecauseExclusive> for T
    where T: ?Sized,

    Source

    impl<T> Same for T

    Source

    type Output = T

    Should always be Self
    Source

    impl<T> ToOwned for T
    where T: Clone,

    Source

    type Owned = T

    The resulting type after obtaining ownership.
    Source

    fn to_owned(&self) -> T

    Creates owned data from borrowed data, usually by cloning. Read more
    Source

    fn clone_into(&self, target: &mut T)

    Uses borrowed data to replace owned data, usually by cloning. Read more
    Source

    impl<T, U> TryFrom<U> for T
    where U: Into<T>,

    Source

    type Error = Infallible

    The type returned in the event of a conversion error.
    Source

    fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

    Performs the conversion.
    Source

    impl<T, U> TryInto<U> for T
    where U: TryFrom<T>,

    Source

    type Error = <U as TryFrom<T>>::Error

    The type returned in the event of a conversion error.
    Source

    fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

    Performs the conversion.
    Source

    impl<T> WithSubscriber for T

    Source

    fn with_subscriber<S>(self, subscriber: S) -> WithDispatch<Self>
    where S: Into<Dispatch>,

    Attaches the provided Subscriber to this type, returning a WithDispatch wrapper. Read more
    Source

    fn with_current_subscriber(self) -> WithDispatch<Self>

    Attaches the current default Subscriber to this type, returning a WithDispatch wrapper. Read more