#[non_exhaustive]pub struct CustomMessageActivity {
pub delivery_uri: Option<String>,
pub endpoint_types: Option<Vec<EndpointTypesElement>>,
pub message_config: Option<JourneyCustomMessage>,
pub next_activity: Option<String>,
pub template_name: Option<String>,
pub template_version: Option<String>,
}Expand description
The settings for a custom message activity. This type of activity calls an AWS Lambda function or web hook that sends messages to participants.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delivery_uri: Option<String>The destination to send the campaign or treatment to. This value can be one of the following:
-
The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
-
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
endpoint_types: Option<Vec<EndpointTypesElement>>The types of endpoints to send the custom message to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.
message_config: Option<JourneyCustomMessage>Specifies the message data included in a custom channel message that's sent to participants in a journey.
next_activity: Option<String>The unique identifier for the next activity to perform, after Amazon Pinpoint calls the AWS Lambda function or web hook.
template_name: Option<String>The name of the custom message template to use for the message. If specified, this value must match the name of an existing message template.
template_version: Option<String>The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versions resource.
If you don't specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that's been most recently reviewed and approved for use, depending on your workflow. It isn't necessarily the latest version of a template.
Implementations
Sourceimpl CustomMessageActivity
impl CustomMessageActivity
Sourcepub fn delivery_uri(&self) -> Option<&str>
pub fn delivery_uri(&self) -> Option<&str>
The destination to send the campaign or treatment to. This value can be one of the following:
-
The name or Amazon Resource Name (ARN) of an AWS Lambda function to invoke to handle delivery of the campaign or treatment.
-
The URL for a web application or service that supports HTTPS and can receive the message. The URL has to be a full URL, including the HTTPS protocol.
Sourcepub fn endpoint_types(&self) -> &[EndpointTypesElement]
pub fn endpoint_types(&self) -> &[EndpointTypesElement]
The types of endpoints to send the custom message to. Each valid value maps to a type of channel that you can associate with an endpoint by using the ChannelType property of an endpoint.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .endpoint_types.is_none().
Sourcepub fn message_config(&self) -> Option<&JourneyCustomMessage>
pub fn message_config(&self) -> Option<&JourneyCustomMessage>
Specifies the message data included in a custom channel message that's sent to participants in a journey.
Sourcepub fn next_activity(&self) -> Option<&str>
pub fn next_activity(&self) -> Option<&str>
The unique identifier for the next activity to perform, after Amazon Pinpoint calls the AWS Lambda function or web hook.
Sourcepub fn template_name(&self) -> Option<&str>
pub fn template_name(&self) -> Option<&str>
The name of the custom message template to use for the message. If specified, this value must match the name of an existing message template.
Sourcepub fn template_version(&self) -> Option<&str>
pub fn template_version(&self) -> Option<&str>
The unique identifier for the version of the message template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versions resource.
If you don't specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that's been most recently reviewed and approved for use, depending on your workflow. It isn't necessarily the latest version of a template.
Sourceimpl CustomMessageActivity
impl CustomMessageActivity
Sourcepub fn builder() -> CustomMessageActivityBuilder
pub fn builder() -> CustomMessageActivityBuilder
Creates a new builder-style object to manufacture CustomMessageActivity.