#[non_exhaustive]pub struct DefaultPushNotificationMessage {
pub action: Option<Action>,
pub body: Option<String>,
pub data: Option<HashMap<String, String>>,
pub silent_push: Option<bool>,
pub substitutions: Option<HashMap<String, Vec<String>>>,
pub title: Option<String>,
pub url: Option<String>,
}Expand description
Specifies the default settings and content for a push notification that's sent directly to an endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: Option<Action>The default action to occur if a recipient taps the push notification. Valid values are:
-
OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
-
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS and Android platforms.
-
URL - The default mobile browser on the recipient's device opens and loads the web page at a URL that you specify.
body: Option<String>The default body of the notification message.
data: Option<HashMap<String, String>>The JSON data payload to use for the default push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.
silent_push: Option<bool>Specifies whether the default notification is a silent push notification, which is a push notification that doesn't display on a recipient's device. Silent push notifications can be used for cases such as updating an app's configuration or delivering messages to an in-app notification center.
substitutions: Option<HashMap<String, Vec<String>>>The default message variables to use in the notification message. You can override the default variables with individual address variables.
title: Option<String>The default title to display above the notification message on a recipient's device.
url: Option<String>The default URL to open in a recipient's default mobile browser, if a recipient taps the push notification and the value of the Action property is URL.
Implementations
Sourceimpl DefaultPushNotificationMessage
impl DefaultPushNotificationMessage
Sourcepub fn action(&self) -> Option<&Action>
pub fn action(&self) -> Option<&Action>
The default action to occur if a recipient taps the push notification. Valid values are:
-
OPEN_APP - Your app opens or it becomes the foreground app if it was sent to the background. This is the default action.
-
DEEP_LINK - Your app opens and displays a designated user interface in the app. This setting uses the deep-linking features of the iOS and Android platforms.
-
URL - The default mobile browser on the recipient's device opens and loads the web page at a URL that you specify.
Sourcepub fn data(&self) -> Option<&HashMap<String, String>>
pub fn data(&self) -> Option<&HashMap<String, String>>
The JSON data payload to use for the default push notification, if the notification is a silent push notification. This payload is added to the data.pinpoint.jsonBody object of the notification.
Sourcepub fn silent_push(&self) -> Option<bool>
pub fn silent_push(&self) -> Option<bool>
Specifies whether the default notification is a silent push notification, which is a push notification that doesn't display on a recipient's device. Silent push notifications can be used for cases such as updating an app's configuration or delivering messages to an in-app notification center.
Sourcepub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>
pub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>
The default message variables to use in the notification message. You can override the default variables with individual address variables.
Sourceimpl DefaultPushNotificationMessage
impl DefaultPushNotificationMessage
Sourcepub fn builder() -> DefaultPushNotificationMessageBuilder
pub fn builder() -> DefaultPushNotificationMessageBuilder
Creates a new builder-style object to manufacture DefaultPushNotificationMessage.