#[non_exhaustive]pub struct DirectMessageConfiguration {
pub adm_message: Option<AdmMessage>,
pub apns_message: Option<ApnsMessage>,
pub baidu_message: Option<BaiduMessage>,
pub default_message: Option<DefaultMessage>,
pub default_push_notification_message: Option<DefaultPushNotificationMessage>,
pub email_message: Option<EmailMessage>,
pub gcm_message: Option<GcmMessage>,
pub sms_message: Option<SmsMessage>,
pub voice_message: Option<VoiceMessage>,
}Expand description
Specifies the settings and content for the default message and any default messages that you tailored for specific channels.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.adm_message: Option<AdmMessage>The default push notification message for the ADM (Amazon Device Messaging) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
apns_message: Option<ApnsMessage>The default push notification message for the APNs (Apple Push Notification service) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
baidu_message: Option<BaiduMessage>The default push notification message for the Baidu (Baidu Cloud Push) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
default_message: Option<DefaultMessage>The default message for all channels.
default_push_notification_message: Option<DefaultPushNotificationMessage>The default push notification message for all push notification channels.
email_message: Option<EmailMessage>The default message for the email channel. This message overrides the default message (DefaultMessage).
gcm_message: Option<GcmMessage>The default push notification message for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message overrides the default push notification message (DefaultPushNotificationMessage).
sms_message: Option<SmsMessage>The default message for the SMS channel. This message overrides the default message (DefaultMessage).
voice_message: Option<VoiceMessage>The default message for the voice channel. This message overrides the default message (DefaultMessage).
Implementations
Sourceimpl DirectMessageConfiguration
impl DirectMessageConfiguration
Sourcepub fn adm_message(&self) -> Option<&AdmMessage>
pub fn adm_message(&self) -> Option<&AdmMessage>
The default push notification message for the ADM (Amazon Device Messaging) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn apns_message(&self) -> Option<&ApnsMessage>
pub fn apns_message(&self) -> Option<&ApnsMessage>
The default push notification message for the APNs (Apple Push Notification service) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn baidu_message(&self) -> Option<&BaiduMessage>
pub fn baidu_message(&self) -> Option<&BaiduMessage>
The default push notification message for the Baidu (Baidu Cloud Push) channel. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn default_message(&self) -> Option<&DefaultMessage>
pub fn default_message(&self) -> Option<&DefaultMessage>
The default message for all channels.
Sourcepub fn default_push_notification_message(
&self,
) -> Option<&DefaultPushNotificationMessage>
pub fn default_push_notification_message( &self, ) -> Option<&DefaultPushNotificationMessage>
The default push notification message for all push notification channels.
Sourcepub fn email_message(&self) -> Option<&EmailMessage>
pub fn email_message(&self) -> Option<&EmailMessage>
The default message for the email channel. This message overrides the default message (DefaultMessage).
Sourcepub fn gcm_message(&self) -> Option<&GcmMessage>
pub fn gcm_message(&self) -> Option<&GcmMessage>
The default push notification message for the GCM channel, which is used to send notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service. This message overrides the default push notification message (DefaultPushNotificationMessage).
Sourcepub fn sms_message(&self) -> Option<&SmsMessage>
pub fn sms_message(&self) -> Option<&SmsMessage>
The default message for the SMS channel. This message overrides the default message (DefaultMessage).
Sourcepub fn voice_message(&self) -> Option<&VoiceMessage>
pub fn voice_message(&self) -> Option<&VoiceMessage>
The default message for the voice channel. This message overrides the default message (DefaultMessage).
Sourceimpl DirectMessageConfiguration
impl DirectMessageConfiguration
Sourcepub fn builder() -> DirectMessageConfigurationBuilder
pub fn builder() -> DirectMessageConfigurationBuilder
Creates a new builder-style object to manufacture DirectMessageConfiguration.