#[non_exhaustive]pub struct EmailChannelRequest {
pub configuration_set: Option<String>,
pub enabled: Option<bool>,
pub from_address: Option<String>,
pub identity: Option<String>,
pub role_arn: Option<String>,
pub orchestration_sending_role_arn: Option<String>,
}Expand description
Specifies the status and settings of the email channel for an application.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.configuration_set: Option<String>The Amazon SES configuration set that you want to apply to messages that you send through the channel.
enabled: Option<bool>Specifies whether to enable the email channel for the application.
from_address: Option<String>The verified email address that you want to send email from when you send email through the channel.
identity: Option<String>The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email Service (Amazon SES), that you want to use when you send email through the channel.
role_arn: Option<String>The ARN of the AWS Identity and Access Management (IAM) role that you want Amazon Pinpoint to use when it submits email-related event data for the channel.
orchestration_sending_role_arn: Option<String>The ARN of an IAM role for Amazon Pinpoint to use to send email from your campaigns or journeys through Amazon SES.
Implementations
Sourceimpl EmailChannelRequest
impl EmailChannelRequest
Sourcepub fn configuration_set(&self) -> Option<&str>
pub fn configuration_set(&self) -> Option<&str>
The Amazon SES configuration set that you want to apply to messages that you send through the channel.
Sourcepub fn enabled(&self) -> Option<bool>
pub fn enabled(&self) -> Option<bool>
Specifies whether to enable the email channel for the application.
Sourcepub fn from_address(&self) -> Option<&str>
pub fn from_address(&self) -> Option<&str>
The verified email address that you want to send email from when you send email through the channel.
Sourcepub fn identity(&self) -> Option<&str>
pub fn identity(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the identity, verified with Amazon Simple Email Service (Amazon SES), that you want to use when you send email through the channel.
Sourcepub fn role_arn(&self) -> Option<&str>
pub fn role_arn(&self) -> Option<&str>
The ARN of the AWS Identity and Access Management (IAM) role that you want Amazon Pinpoint to use when it submits email-related event data for the channel.
Sourcepub fn orchestration_sending_role_arn(&self) -> Option<&str>
pub fn orchestration_sending_role_arn(&self) -> Option<&str>
The ARN of an IAM role for Amazon Pinpoint to use to send email from your campaigns or journeys through Amazon SES.
Sourceimpl EmailChannelRequest
impl EmailChannelRequest
Sourcepub fn builder() -> EmailChannelRequestBuilder
pub fn builder() -> EmailChannelRequestBuilder
Creates a new builder-style object to manufacture EmailChannelRequest.