EmailMessage

Struct EmailMessage 

#[non_exhaustive]
pub struct EmailMessage { pub body: Option<String>, pub feedback_forwarding_address: Option<String>, pub from_address: Option<String>, pub raw_email: Option<RawEmail>, pub reply_to_addresses: Option<Vec<String>>, pub simple_email: Option<SimpleEmail>, pub substitutions: Option<HashMap<String, Vec<String>>>, }
Specifies the default settings and content for a one-time email message that's sent directly to an endpoint.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
body: Option<String>

The body of the email message.

feedback_forwarding_address: Option<String>

The email address to forward bounces and complaints to, if feedback forwarding is enabled.

from_address: Option<String>

The verified email address to send the email message from. The default value is the FromAddress specified for the email channel.

raw_email: Option<RawEmail>

The email message, represented as a raw MIME message.

reply_to_addresses: Option<Vec<String>>

The reply-to email address(es) for the email message. If a recipient replies to the email, each reply-to address receives the reply.

simple_email: Option<SimpleEmail>

The email message, composed of a subject, a text part, and an HTML part.

substitutions: Option<HashMap<String, Vec<String>>>

The default message variables to use in the email message. You can override the default variables with individual address variables.

Implementations

Source

impl EmailMessage

pub fn body(&self) -> Option<&str>

The body of the email message.

pub fn feedback_forwarding_address(&self) -> Option<&str>

The email address to forward bounces and complaints to, if feedback forwarding is enabled.

pub fn from_address(&self) -> Option<&str>

The verified email address to send the email message from. The default value is the FromAddress specified for the email channel.

pub fn raw_email(&self) -> Option<&RawEmail>

The email message, represented as a raw MIME message.

pub fn reply_to_addresses(&self) -> &[String]

The reply-to email address(es) for the email message. If a recipient replies to the email, each reply-to address receives the reply.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .reply_to_addresses.is_none().

pub fn simple_email(&self) -> Option<&SimpleEmail>

The email message, composed of a subject, a text part, and an HTML part.

pub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>

The default message variables to use in the email message. You can override the default variables with individual address variables.

Source

impl EmailMessage

pub fn builder() -> EmailMessageBuilder

Creates a new builder-style object to manufacture EmailMessage.