#[non_exhaustive]pub struct EmailMessageActivity {
pub message_config: Option<JourneyEmailMessage>,
pub next_activity: Option<String>,
pub template_name: Option<String>,
pub template_version: Option<String>,
}Expand description
Specifies the settings for an email activity in a journey. This type of activity sends an email message to participants.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message_config: Option<JourneyEmailMessage>Specifies the sender address for an email message that's sent to participants in the journey.
next_activity: Option<String>The unique identifier for the next activity to perform, after the message is sent.
template_name: Option<String>The name of the email message template to use for the message. If specified, this value must match the name of an existing message template.
template_version: Option<String>The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versions resource.
If you don't specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that's been most recently reviewed and approved for use, depending on your workflow. It isn't necessarily the latest version of a template.
Implementations
Sourceimpl EmailMessageActivity
impl EmailMessageActivity
Sourcepub fn message_config(&self) -> Option<&JourneyEmailMessage>
pub fn message_config(&self) -> Option<&JourneyEmailMessage>
Specifies the sender address for an email message that's sent to participants in the journey.
Sourcepub fn next_activity(&self) -> Option<&str>
pub fn next_activity(&self) -> Option<&str>
The unique identifier for the next activity to perform, after the message is sent.
Sourcepub fn template_name(&self) -> Option<&str>
pub fn template_name(&self) -> Option<&str>
The name of the email message template to use for the message. If specified, this value must match the name of an existing message template.
Sourcepub fn template_version(&self) -> Option<&str>
pub fn template_version(&self) -> Option<&str>
The unique identifier for the version of the email template to use for the message. If specified, this value must match the identifier for an existing template version. To retrieve a list of versions and version identifiers for a template, use the Template Versions resource.
If you don't specify a value for this property, Amazon Pinpoint uses the active version of the template. The active version is typically the version of a template that's been most recently reviewed and approved for use, depending on your workflow. It isn't necessarily the latest version of a template.
Sourceimpl EmailMessageActivity
impl EmailMessageActivity
Sourcepub fn builder() -> EmailMessageActivityBuilder
pub fn builder() -> EmailMessageActivityBuilder
Creates a new builder-style object to manufacture EmailMessageActivity.