#[non_exhaustive]pub struct EndpointSendConfiguration {
pub body_override: Option<String>,
pub context: Option<HashMap<String, String>>,
pub raw_content: Option<String>,
pub substitutions: Option<HashMap<String, Vec<String>>>,
pub title_override: Option<String>,
}Expand description
Specifies the content, including message variables and attributes, to use in a message that's sent directly to an endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.body_override: Option<String>The body of the message. If specified, this value overrides the default message body.
context: Option<HashMap<String, String>>A map of custom attributes to attach to the message for the address. Attribute names are case sensitive.
For a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.
raw_content: Option<String>The raw, JSON-formatted string to use as the payload for the message. If specified, this value overrides all other values for the message.
substitutions: Option<HashMap<String, Vec<String>>>A map of the message variables to merge with the variables specified for the default message (DefaultMessage.Substitutions). The variables specified in this map take precedence over all other variables.
title_override: Option<String>The title or subject line of the message. If specified, this value overrides the default message title or subject line.
Implementations
Sourceimpl EndpointSendConfiguration
impl EndpointSendConfiguration
Sourcepub fn body_override(&self) -> Option<&str>
pub fn body_override(&self) -> Option<&str>
The body of the message. If specified, this value overrides the default message body.
Sourcepub fn context(&self) -> Option<&HashMap<String, String>>
pub fn context(&self) -> Option<&HashMap<String, String>>
A map of custom attributes to attach to the message for the address. Attribute names are case sensitive.
For a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.
Sourcepub fn raw_content(&self) -> Option<&str>
pub fn raw_content(&self) -> Option<&str>
The raw, JSON-formatted string to use as the payload for the message. If specified, this value overrides all other values for the message.
Sourcepub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>
pub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>
A map of the message variables to merge with the variables specified for the default message (DefaultMessage.Substitutions). The variables specified in this map take precedence over all other variables.
Sourcepub fn title_override(&self) -> Option<&str>
pub fn title_override(&self) -> Option<&str>
The title or subject line of the message. If specified, this value overrides the default message title or subject line.
Sourceimpl EndpointSendConfiguration
impl EndpointSendConfiguration
Sourcepub fn builder() -> EndpointSendConfigurationBuilder
pub fn builder() -> EndpointSendConfigurationBuilder
Creates a new builder-style object to manufacture EndpointSendConfiguration.