#[non_exhaustive]pub struct EventsRequest {
pub batch_item: Option<HashMap<String, EventsBatch>>,
}Expand description
Specifies a batch of events to process.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.batch_item: Option<HashMap<String, EventsBatch>>The batch of events to process. For each item in a batch, the endpoint ID acts as a key that has an EventsBatch object as its value.
Implementations
Sourceimpl EventsRequest
impl EventsRequest
Sourcepub fn batch_item(&self) -> Option<&HashMap<String, EventsBatch>>
pub fn batch_item(&self) -> Option<&HashMap<String, EventsBatch>>
The batch of events to process. For each item in a batch, the endpoint ID acts as a key that has an EventsBatch object as its value.
Sourceimpl EventsRequest
impl EventsRequest
Sourcepub fn builder() -> EventsRequestBuilder
pub fn builder() -> EventsRequestBuilder
Creates a new builder-style object to manufacture EventsRequest.