#[non_exhaustive]pub struct ImportJobRequest {
pub define_segment: Option<bool>,
pub external_id: Option<String>,
pub format: Option<Format>,
pub register_endpoints: Option<bool>,
pub role_arn: Option<String>,
pub s3_url: Option<String>,
pub segment_id: Option<String>,
pub segment_name: Option<String>,
}Expand description
Specifies the settings for a job that imports endpoint definitions from an Amazon Simple Storage Service (Amazon S3) bucket.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.define_segment: Option<bool>Specifies whether to create a segment that contains the endpoints, when the endpoint definitions are imported.
external_id: Option<String>(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don't recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.
format: Option<Format>The format of the files that contain the endpoint definitions to import. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format. If the Amazon S3 location stores multiple files that use different formats, Amazon Pinpoint imports data only from the files that use the specified format.
register_endpoints: Option<bool>Specifies whether to register the endpoints with Amazon Pinpoint, when the endpoint definitions are imported.
role_arn: Option<String>The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.
s3_url: Option<String>The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the endpoint definitions to import. This location can be a folder or a single file. If the location is a folder, Amazon Pinpoint imports endpoint definitions from the files in this location, including any subfolders that the folder contains.
The URL should be in the following format: s3://
segment_id: Option<String>The identifier for the segment to update or add the imported endpoint definitions to, if the import job is meant to update an existing segment.
segment_name: Option<String>A custom name for the segment that's created by the import job, if the value of the DefineSegment property is true.
Implementations
Sourceimpl ImportJobRequest
impl ImportJobRequest
Sourcepub fn define_segment(&self) -> Option<bool>
pub fn define_segment(&self) -> Option<bool>
Specifies whether to create a segment that contains the endpoints, when the endpoint definitions are imported.
Sourcepub fn external_id(&self) -> Option<&str>
pub fn external_id(&self) -> Option<&str>
(Deprecated) Your AWS account ID, which you assigned to an external ID key in an IAM trust policy. Amazon Pinpoint previously used this value to assume an IAM role when importing endpoint definitions, but we removed this requirement. We don't recommend use of external IDs for IAM roles that are assumed by Amazon Pinpoint.
Sourcepub fn format(&self) -> Option<&Format>
pub fn format(&self) -> Option<&Format>
The format of the files that contain the endpoint definitions to import. Valid values are: CSV, for comma-separated values format; and, JSON, for newline-delimited JSON format. If the Amazon S3 location stores multiple files that use different formats, Amazon Pinpoint imports data only from the files that use the specified format.
Sourcepub fn register_endpoints(&self) -> Option<bool>
pub fn register_endpoints(&self) -> Option<bool>
Specifies whether to register the endpoints with Amazon Pinpoint, when the endpoint definitions are imported.
Sourcepub fn role_arn(&self) -> Option<&str>
pub fn role_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to access the Amazon S3 location to import endpoint definitions from.
Sourcepub fn s3_url(&self) -> Option<&str>
pub fn s3_url(&self) -> Option<&str>
The URL of the Amazon Simple Storage Service (Amazon S3) bucket that contains the endpoint definitions to import. This location can be a folder or a single file. If the location is a folder, Amazon Pinpoint imports endpoint definitions from the files in this location, including any subfolders that the folder contains.
The URL should be in the following format: s3://
Sourcepub fn segment_id(&self) -> Option<&str>
pub fn segment_id(&self) -> Option<&str>
The identifier for the segment to update or add the imported endpoint definitions to, if the import job is meant to update an existing segment.
Sourcepub fn segment_name(&self) -> Option<&str>
pub fn segment_name(&self) -> Option<&str>
A custom name for the segment that's created by the import job, if the value of the DefineSegment property is true.
Sourceimpl ImportJobRequest
impl ImportJobRequest
Sourcepub fn builder() -> ImportJobRequestBuilder
pub fn builder() -> ImportJobRequestBuilder
Creates a new builder-style object to manufacture ImportJobRequest.