#[non_exhaustive]pub struct MessageRequest {
pub addresses: Option<HashMap<String, AddressConfiguration>>,
pub context: Option<HashMap<String, String>>,
pub endpoints: Option<HashMap<String, EndpointSendConfiguration>>,
pub message_configuration: Option<DirectMessageConfiguration>,
pub template_configuration: Option<TemplateConfiguration>,
pub trace_id: Option<String>,
}Expand description
Specifies the configuration and other settings for a message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.addresses: Option<HashMap<String, AddressConfiguration>>A map of key-value pairs, where each key is an address and each value is an AddressConfiguration object. An address can be a push notification token, a phone number, or an email address. You can use an AddressConfiguration object to tailor the message for an address by specifying settings such as content overrides and message variables.
context: Option<HashMap<String, String>>A map of custom attributes to attach to the message. For a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.
endpoints: Option<HashMap<String, EndpointSendConfiguration>>A map of key-value pairs, where each key is an endpoint ID and each value is an EndpointSendConfiguration object. You can use an EndpointSendConfiguration object to tailor the message for an endpoint by specifying settings such as content overrides and message variables.
message_configuration: Option<DirectMessageConfiguration>The settings and content for the default message and any default messages that you defined for specific channels.
template_configuration: Option<TemplateConfiguration>The message template to use for the message.
trace_id: Option<String>The unique identifier for tracing the message. This identifier is visible to message recipients.
Implementations
Sourceimpl MessageRequest
impl MessageRequest
Sourcepub fn addresses(&self) -> Option<&HashMap<String, AddressConfiguration>>
pub fn addresses(&self) -> Option<&HashMap<String, AddressConfiguration>>
A map of key-value pairs, where each key is an address and each value is an AddressConfiguration object. An address can be a push notification token, a phone number, or an email address. You can use an AddressConfiguration object to tailor the message for an address by specifying settings such as content overrides and message variables.
Sourcepub fn context(&self) -> Option<&HashMap<String, String>>
pub fn context(&self) -> Option<&HashMap<String, String>>
A map of custom attributes to attach to the message. For a push notification, this payload is added to the data.pinpoint object. For an email or text message, this payload is added to email/SMS delivery receipt event attributes.
Sourcepub fn endpoints(&self) -> Option<&HashMap<String, EndpointSendConfiguration>>
pub fn endpoints(&self) -> Option<&HashMap<String, EndpointSendConfiguration>>
A map of key-value pairs, where each key is an endpoint ID and each value is an EndpointSendConfiguration object. You can use an EndpointSendConfiguration object to tailor the message for an endpoint by specifying settings such as content overrides and message variables.
Sourcepub fn message_configuration(&self) -> Option<&DirectMessageConfiguration>
pub fn message_configuration(&self) -> Option<&DirectMessageConfiguration>
The settings and content for the default message and any default messages that you defined for specific channels.
Sourcepub fn template_configuration(&self) -> Option<&TemplateConfiguration>
pub fn template_configuration(&self) -> Option<&TemplateConfiguration>
The message template to use for the message.
Sourceimpl MessageRequest
impl MessageRequest
Sourcepub fn builder() -> MessageRequestBuilder
pub fn builder() -> MessageRequestBuilder
Creates a new builder-style object to manufacture MessageRequest.