#[non_exhaustive]pub struct MultiConditionalBranch {
pub condition: Option<SimpleCondition>,
pub next_activity: Option<String>,
}Expand description
Specifies a condition to evaluate for an activity path in a journey.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.condition: Option<SimpleCondition>The condition to evaluate for the activity path.
next_activity: Option<String>The unique identifier for the next activity to perform, after completing the activity for the path.
Implementations
Sourceimpl MultiConditionalBranch
impl MultiConditionalBranch
Sourcepub fn condition(&self) -> Option<&SimpleCondition>
pub fn condition(&self) -> Option<&SimpleCondition>
The condition to evaluate for the activity path.
Sourcepub fn next_activity(&self) -> Option<&str>
pub fn next_activity(&self) -> Option<&str>
The unique identifier for the next activity to perform, after completing the activity for the path.
Sourceimpl MultiConditionalBranch
impl MultiConditionalBranch
Sourcepub fn builder() -> MultiConditionalBranchBuilder
pub fn builder() -> MultiConditionalBranchBuilder
Creates a new builder-style object to manufacture MultiConditionalBranch.