#[non_exhaustive]pub struct MultiConditionalSplitActivity {
pub branches: Option<Vec<MultiConditionalBranch>>,
pub default_activity: Option<String>,
pub evaluation_wait_time: Option<WaitTime>,
}Expand description
Specifies the settings for a multivariate split activity in a journey. This type of activity sends participants down one of as many as five paths (including a default Else path) in a journey, based on conditions that you specify.
To create multivariate split activities that send participants down different paths based on push notification events (such as Open or Received events), your mobile app has to specify the User ID and Endpoint ID values. For more information, see Integrating Amazon Pinpoint with your application in the Amazon Pinpoint Developer Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.branches: Option<Vec<MultiConditionalBranch>>The paths for the activity, including the conditions for entering each path and the activity to perform for each path.
default_activity: Option<String>The unique identifier for the activity to perform for participants who don't meet any of the conditions specified for other paths in the activity.
evaluation_wait_time: Option<WaitTime>The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.
Implementations
Sourceimpl MultiConditionalSplitActivity
impl MultiConditionalSplitActivity
Sourcepub fn branches(&self) -> &[MultiConditionalBranch]
pub fn branches(&self) -> &[MultiConditionalBranch]
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .branches.is_none().
Sourcepub fn default_activity(&self) -> Option<&str>
pub fn default_activity(&self) -> Option<&str>
The unique identifier for the activity to perform for participants who don't meet any of the conditions specified for other paths in the activity.
Sourcepub fn evaluation_wait_time(&self) -> Option<&WaitTime>
pub fn evaluation_wait_time(&self) -> Option<&WaitTime>
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.
Sourceimpl MultiConditionalSplitActivity
impl MultiConditionalSplitActivity
Sourcepub fn builder() -> MultiConditionalSplitActivityBuilder
pub fn builder() -> MultiConditionalSplitActivityBuilder
Creates a new builder-style object to manufacture MultiConditionalSplitActivity.