#[non_exhaustive]pub struct RandomSplitEntry {
pub next_activity: Option<String>,
pub percentage: Option<i32>,
}Expand description
Specifies the settings for a path in a random split activity in a journey.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_activity: Option<String>The unique identifier for the next activity to perform, after completing the activity for the path.
percentage: Option<i32>The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.
Implementations
Sourceimpl RandomSplitEntry
impl RandomSplitEntry
Sourcepub fn next_activity(&self) -> Option<&str>
pub fn next_activity(&self) -> Option<&str>
The unique identifier for the next activity to perform, after completing the activity for the path.
Sourcepub fn percentage(&self) -> Option<i32>
pub fn percentage(&self) -> Option<i32>
The percentage of participants to send down the activity path.
To determine which participants are sent down each path, Amazon Pinpoint applies a probability-based algorithm to the percentages that you specify for the paths. Therefore, the actual percentage of participants who are sent down a path may not be equal to the percentage that you specify.
Sourceimpl RandomSplitEntry
impl RandomSplitEntry
Sourcepub fn builder() -> RandomSplitEntryBuilder
pub fn builder() -> RandomSplitEntryBuilder
Creates a new builder-style object to manufacture RandomSplitEntry.