#[non_exhaustive]pub struct SendOtpMessageRequestParameters {
pub allowed_attempts: Option<i32>,
pub brand_name: Option<String>,
pub channel: Option<String>,
pub code_length: Option<i32>,
pub destination_identity: Option<String>,
pub entity_id: Option<String>,
pub language: Option<String>,
pub origination_identity: Option<String>,
pub reference_id: Option<String>,
pub template_id: Option<String>,
pub validity_period: Option<i32>,
}Expand description
Send OTP message request parameters.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.allowed_attempts: Option<i32>The attempts allowed to validate an OTP.
brand_name: Option<String>The brand name that will be substituted into the OTP message body. Should be owned by calling AWS account.
channel: Option<String>Channel type for the OTP message. Supported values: \[SMS\].
code_length: Option<i32>The number of characters in the generated OTP.
destination_identity: Option<String>The destination identity to send OTP to.
entity_id: Option<String>A unique Entity ID received from DLT after entity registration is approved.
language: Option<String>The language to be used for the outgoing message body containing the OTP.
origination_identity: Option<String>The origination identity used to send OTP from.
reference_id: Option<String>Developer-specified reference identifier. Required to match during OTP verification.
template_id: Option<String>A unique Template ID received from DLT after entity registration is approved.
validity_period: Option<i32>The time in minutes before the OTP is no longer valid.
Implementations
Sourceimpl SendOtpMessageRequestParameters
impl SendOtpMessageRequestParameters
Sourcepub fn allowed_attempts(&self) -> Option<i32>
pub fn allowed_attempts(&self) -> Option<i32>
The attempts allowed to validate an OTP.
Sourcepub fn brand_name(&self) -> Option<&str>
pub fn brand_name(&self) -> Option<&str>
The brand name that will be substituted into the OTP message body. Should be owned by calling AWS account.
Sourcepub fn channel(&self) -> Option<&str>
pub fn channel(&self) -> Option<&str>
Channel type for the OTP message. Supported values: \[SMS\].
Sourcepub fn code_length(&self) -> Option<i32>
pub fn code_length(&self) -> Option<i32>
The number of characters in the generated OTP.
Sourcepub fn destination_identity(&self) -> Option<&str>
pub fn destination_identity(&self) -> Option<&str>
The destination identity to send OTP to.
Sourcepub fn entity_id(&self) -> Option<&str>
pub fn entity_id(&self) -> Option<&str>
A unique Entity ID received from DLT after entity registration is approved.
Sourcepub fn language(&self) -> Option<&str>
pub fn language(&self) -> Option<&str>
The language to be used for the outgoing message body containing the OTP.
Sourcepub fn origination_identity(&self) -> Option<&str>
pub fn origination_identity(&self) -> Option<&str>
The origination identity used to send OTP from.
Sourcepub fn reference_id(&self) -> Option<&str>
pub fn reference_id(&self) -> Option<&str>
Developer-specified reference identifier. Required to match during OTP verification.
Sourcepub fn template_id(&self) -> Option<&str>
pub fn template_id(&self) -> Option<&str>
A unique Template ID received from DLT after entity registration is approved.
Sourcepub fn validity_period(&self) -> Option<i32>
pub fn validity_period(&self) -> Option<i32>
The time in minutes before the OTP is no longer valid.
Sourceimpl SendOtpMessageRequestParameters
impl SendOtpMessageRequestParameters
Sourcepub fn builder() -> SendOtpMessageRequestParametersBuilder
pub fn builder() -> SendOtpMessageRequestParametersBuilder
Creates a new builder-style object to manufacture SendOtpMessageRequestParameters.