#[non_exhaustive]pub struct SendUsersMessageRequest {
pub context: Option<HashMap<String, String>>,
pub message_configuration: Option<DirectMessageConfiguration>,
pub template_configuration: Option<TemplateConfiguration>,
pub trace_id: Option<String>,
pub users: Option<HashMap<String, EndpointSendConfiguration>>,
}Expand description
Specifies the configuration and other settings for a message to send to all the endpoints that are associated with a list of users.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.context: Option<HashMap<String, String>>A map of custom attribute-value pairs. For a push notification, Amazon Pinpoint adds these attributes to the data.pinpoint object in the body of the notification payload. Amazon Pinpoint also provides these attributes in the events that it generates for users-messages deliveries.
message_configuration: Option<DirectMessageConfiguration>The settings and content for the default message and any default messages that you defined for specific channels.
template_configuration: Option<TemplateConfiguration>The message template to use for the message.
trace_id: Option<String>The unique identifier for tracing the message. This identifier is visible to message recipients.
users: Option<HashMap<String, EndpointSendConfiguration>>A map that associates user IDs with EndpointSendConfiguration objects. You can use an EndpointSendConfiguration object to tailor the message for a user by specifying settings such as content overrides and message variables.
Implementations
Sourceimpl SendUsersMessageRequest
impl SendUsersMessageRequest
Sourcepub fn context(&self) -> Option<&HashMap<String, String>>
pub fn context(&self) -> Option<&HashMap<String, String>>
A map of custom attribute-value pairs. For a push notification, Amazon Pinpoint adds these attributes to the data.pinpoint object in the body of the notification payload. Amazon Pinpoint also provides these attributes in the events that it generates for users-messages deliveries.
Sourcepub fn message_configuration(&self) -> Option<&DirectMessageConfiguration>
pub fn message_configuration(&self) -> Option<&DirectMessageConfiguration>
The settings and content for the default message and any default messages that you defined for specific channels.
Sourcepub fn template_configuration(&self) -> Option<&TemplateConfiguration>
pub fn template_configuration(&self) -> Option<&TemplateConfiguration>
The message template to use for the message.
Sourcepub fn trace_id(&self) -> Option<&str>
pub fn trace_id(&self) -> Option<&str>
The unique identifier for tracing the message. This identifier is visible to message recipients.
Sourcepub fn users(&self) -> Option<&HashMap<String, EndpointSendConfiguration>>
pub fn users(&self) -> Option<&HashMap<String, EndpointSendConfiguration>>
A map that associates user IDs with EndpointSendConfiguration objects. You can use an EndpointSendConfiguration object to tailor the message for a user by specifying settings such as content overrides and message variables.
Sourceimpl SendUsersMessageRequest
impl SendUsersMessageRequest
Sourcepub fn builder() -> SendUsersMessageRequestBuilder
pub fn builder() -> SendUsersMessageRequestBuilder
Creates a new builder-style object to manufacture SendUsersMessageRequest.