#[non_exhaustive]pub struct SimpleEmail {
pub html_part: Option<SimpleEmailPart>,
pub subject: Option<SimpleEmailPart>,
pub text_part: Option<SimpleEmailPart>,
pub headers: Option<Vec<MessageHeader>>,
}Expand description
Specifies the contents of an email message, composed of a subject, a text part, and an HTML part.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.html_part: Option<SimpleEmailPart>The body of the email message, in HTML format. We recommend using HTML format for email clients that render HTML content. You can include links, formatted text, and more in an HTML message.
subject: Option<SimpleEmailPart>The subject line, or title, of the email.
text_part: Option<SimpleEmailPart>The body of the email message, in plain text format. We recommend using plain text format for email clients that don't render HTML content and clients that are connected to high-latency networks, such as mobile devices.
headers: Option<Vec<MessageHeader>>The list of MessageHeaders for the email. You can have up to 15 Headers.
Implementations
Sourceimpl SimpleEmail
impl SimpleEmail
Sourcepub fn html_part(&self) -> Option<&SimpleEmailPart>
pub fn html_part(&self) -> Option<&SimpleEmailPart>
The body of the email message, in HTML format. We recommend using HTML format for email clients that render HTML content. You can include links, formatted text, and more in an HTML message.
Sourcepub fn subject(&self) -> Option<&SimpleEmailPart>
pub fn subject(&self) -> Option<&SimpleEmailPart>
The subject line, or title, of the email.
Sourcepub fn text_part(&self) -> Option<&SimpleEmailPart>
pub fn text_part(&self) -> Option<&SimpleEmailPart>
The body of the email message, in plain text format. We recommend using plain text format for email clients that don't render HTML content and clients that are connected to high-latency networks, such as mobile devices.
Sourcepub fn headers(&self) -> &[MessageHeader]
pub fn headers(&self) -> &[MessageHeader]
The list of MessageHeaders for the email. You can have up to 15 Headers.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .headers.is_none().
Sourceimpl SimpleEmail
impl SimpleEmail
Sourcepub fn builder() -> SimpleEmailBuilder
pub fn builder() -> SimpleEmailBuilder
Creates a new builder-style object to manufacture SimpleEmail.