#[non_exhaustive]pub struct SmsMessage {
pub body: Option<String>,
pub keyword: Option<String>,
pub media_url: Option<String>,
pub message_type: Option<MessageType>,
pub origination_number: Option<String>,
pub sender_id: Option<String>,
pub substitutions: Option<HashMap<String, Vec<String>>>,
pub entity_id: Option<String>,
pub template_id: Option<String>,
}Expand description
Specifies the default settings for a one-time SMS message that's sent directly to an endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.body: Option<String>The body of the SMS message.
keyword: Option<String>The SMS program name that you provided to AWS Support when you requested your dedicated number.
media_url: Option<String>This field is reserved for future use.
message_type: Option<MessageType>The SMS message type. Valid values are TRANSACTIONAL (for messages that are critical or time-sensitive, such as a one-time passwords) and PROMOTIONAL (for messsages that aren't critical or time-sensitive, such as marketing messages).
origination_number: Option<String>The number to send the SMS message from. This value should be one of the dedicated long or short codes that's assigned to your AWS account. If you don't specify a long or short code, Amazon Pinpoint assigns a random long code to the SMS message and sends the message from that code.
sender_id: Option<String>The sender ID to display as the sender of the message on a recipient's device. Support for sender IDs varies by country or region.
substitutions: Option<HashMap<String, Vec<String>>>The message variables to use in the SMS message. You can override the default variables with individual address variables.
entity_id: Option<String>The entity ID or Principal Entity (PE) id received from the regulatory body for sending SMS in your country.
template_id: Option<String>The template ID received from the regulatory body for sending SMS in your country.
Implementations
Sourceimpl SmsMessage
impl SmsMessage
Sourcepub fn keyword(&self) -> Option<&str>
pub fn keyword(&self) -> Option<&str>
The SMS program name that you provided to AWS Support when you requested your dedicated number.
Sourcepub fn message_type(&self) -> Option<&MessageType>
pub fn message_type(&self) -> Option<&MessageType>
The SMS message type. Valid values are TRANSACTIONAL (for messages that are critical or time-sensitive, such as a one-time passwords) and PROMOTIONAL (for messsages that aren't critical or time-sensitive, such as marketing messages).
Sourcepub fn origination_number(&self) -> Option<&str>
pub fn origination_number(&self) -> Option<&str>
The number to send the SMS message from. This value should be one of the dedicated long or short codes that's assigned to your AWS account. If you don't specify a long or short code, Amazon Pinpoint assigns a random long code to the SMS message and sends the message from that code.
Sourcepub fn sender_id(&self) -> Option<&str>
pub fn sender_id(&self) -> Option<&str>
The sender ID to display as the sender of the message on a recipient's device. Support for sender IDs varies by country or region.
Sourcepub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>
pub fn substitutions(&self) -> Option<&HashMap<String, Vec<String>>>
The message variables to use in the SMS message. You can override the default variables with individual address variables.
Sourcepub fn entity_id(&self) -> Option<&str>
pub fn entity_id(&self) -> Option<&str>
The entity ID or Principal Entity (PE) id received from the regulatory body for sending SMS in your country.
Sourcepub fn template_id(&self) -> Option<&str>
pub fn template_id(&self) -> Option<&str>
The template ID received from the regulatory body for sending SMS in your country.
Sourceimpl SmsMessage
impl SmsMessage
Sourcepub fn builder() -> SmsMessageBuilder
pub fn builder() -> SmsMessageBuilder
Creates a new builder-style object to manufacture SmsMessage.