#[non_exhaustive]pub struct WaitActivity {
pub next_activity: Option<String>,
pub wait_time: Option<WaitTime>,
}Expand description
Specifies the settings for a wait activity in a journey. This type of activity waits for a certain amount of time or until a specific date and time before moving participants to the next activity in a journey.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_activity: Option<String>The unique identifier for the next activity to perform, after performing the wait activity.
wait_time: Option<WaitTime>The amount of time to wait or the date and time when the activity moves participants to the next activity in the journey.
Implementations
Sourceimpl WaitActivity
impl WaitActivity
Sourcepub fn next_activity(&self) -> Option<&str>
pub fn next_activity(&self) -> Option<&str>
The unique identifier for the next activity to perform, after performing the wait activity.
Sourceimpl WaitActivity
impl WaitActivity
Sourcepub fn builder() -> WaitActivityBuilder
pub fn builder() -> WaitActivityBuilder
Creates a new builder-style object to manufacture WaitActivity.