#[non_exhaustive]pub struct WaitTime {
pub wait_for: Option<String>,
pub wait_until: Option<String>,
}Expand description
Specifies a duration or a date and time that indicates when Amazon Pinpoint determines whether an activity's conditions have been met or an activity moves participants to the next activity in a journey.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.wait_for: Option<String>The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity's conditions have been met or moving participants to the next activity in the journey.
wait_until: Option<String>The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity's conditions have been met or the activity moves participants to the next activity in the journey.
Implementations
Sourceimpl WaitTime
impl WaitTime
Sourcepub fn wait_for(&self) -> Option<&str>
pub fn wait_for(&self) -> Option<&str>
The amount of time to wait, as a duration in ISO 8601 format, before determining whether the activity's conditions have been met or moving participants to the next activity in the journey.
Sourcepub fn wait_until(&self) -> Option<&str>
pub fn wait_until(&self) -> Option<&str>
The date and time, in ISO 8601 format, when Amazon Pinpoint determines whether the activity's conditions have been met or the activity moves participants to the next activity in the journey.