WriteCampaignRequest

Struct WriteCampaignRequest 

#[non_exhaustive]
pub struct WriteCampaignRequest {
Show 17 fields pub additional_treatments: Option<Vec<WriteTreatmentResource>>, pub custom_delivery_configuration: Option<CustomDeliveryConfiguration>, pub description: Option<String>, pub holdout_percent: Option<i32>, pub hook: Option<CampaignHook>, pub is_paused: Option<bool>, pub limits: Option<CampaignLimits>, pub message_configuration: Option<MessageConfiguration>, pub name: Option<String>, pub schedule: Option<Schedule>, pub segment_id: Option<String>, pub segment_version: Option<i32>, pub tags: Option<HashMap<String, String>>, pub template_configuration: Option<TemplateConfiguration>, pub treatment_description: Option<String>, pub treatment_name: Option<String>, pub priority: Option<i32>,
}
Specifies the configuration and other settings for a campaign.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
additional_treatments: Option<Vec<WriteTreatmentResource>>

An array of requests that defines additional treatments for the campaign, in addition to the default treatment for the campaign.

custom_delivery_configuration: Option<CustomDeliveryConfiguration>

The delivery configuration settings for sending the campaign through a custom channel. This object is required if the MessageConfiguration object for the campaign specifies a CustomMessage object.

description: Option<String>

A custom description of the campaign.

holdout_percent: Option<i32>

The allocated percentage of users (segment members) who shouldn't receive messages from the campaign.

hook: Option<CampaignHook>

The settings for the AWS Lambda function to invoke as a code hook for the campaign. You can use this hook to customize the segment that's used by the campaign.

is_paused: Option<bool>

Specifies whether to pause the campaign. A paused campaign doesn't run unless you resume it by changing this value to false.

limits: Option<CampaignLimits>

The messaging limits for the campaign.

message_configuration: Option<MessageConfiguration>

The message configuration settings for the campaign.

name: Option<String>

A custom name for the campaign.

schedule: Option<Schedule>

The schedule settings for the campaign.

segment_id: Option<String>

The unique identifier for the segment to associate with the campaign.

segment_version: Option<i32>

The version of the segment to associate with the campaign.

tags: Option<HashMap<String, String>>

As of 22-05-2023 tags has been deprecated for update operations. After this date any value in tags is not processed and an error code is not returned. To manage tags we recommend using either Tags in the API Reference for Amazon Pinpoint, resourcegroupstaggingapi commands in the AWS Command Line Interface Documentation or resourcegroupstaggingapi in the AWS SDK.

(Deprecated) A string-to-string map of key-value pairs that defines the tags to associate with the campaign. Each tag consists of a required tag key and an associated tag value.

template_configuration: Option<TemplateConfiguration>

The message template to use for the campaign.

treatment_description: Option<String>

A custom description of the default treatment for the campaign.

treatment_name: Option<String>

A custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that's used for A/B testing.

priority: Option<i32>

Defines the priority of the campaign, used to decide the order of messages displayed to user if there are multiple messages scheduled to be displayed at the same moment.

Implementations

Source

impl WriteCampaignRequest

pub fn additional_treatments(&self) -> &[WriteTreatmentResource]

An array of requests that defines additional treatments for the campaign, in addition to the default treatment for the campaign.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .additional_treatments.is_none().

pub fn custom_delivery_configuration( &self, ) -> Option<&CustomDeliveryConfiguration>

The delivery configuration settings for sending the campaign through a custom channel. This object is required if the MessageConfiguration object for the campaign specifies a CustomMessage object.

pub fn description(&self) -> Option<&str>

A custom description of the campaign.

pub fn holdout_percent(&self) -> Option<i32>

The allocated percentage of users (segment members) who shouldn't receive messages from the campaign.

pub fn hook(&self) -> Option<&CampaignHook>

The settings for the AWS Lambda function to invoke as a code hook for the campaign. You can use this hook to customize the segment that's used by the campaign.

pub fn is_paused(&self) -> Option<bool>

Specifies whether to pause the campaign. A paused campaign doesn't run unless you resume it by changing this value to false.

pub fn limits(&self) -> Option<&CampaignLimits>

The messaging limits for the campaign.

pub fn message_configuration(&self) -> Option<&MessageConfiguration>

The message configuration settings for the campaign.

pub fn name(&self) -> Option<&str>

A custom name for the campaign.

pub fn schedule(&self) -> Option<&Schedule>

The schedule settings for the campaign.

pub fn segment_id(&self) -> Option<&str>

The unique identifier for the segment to associate with the campaign.

pub fn segment_version(&self) -> Option<i32>

The version of the segment to associate with the campaign.

pub fn tags(&self) -> Option<&HashMap<String, String>>

As of 22-05-2023 tags has been deprecated for update operations. After this date any value in tags is not processed and an error code is not returned. To manage tags we recommend using either Tags in the API Reference for Amazon Pinpoint, resourcegroupstaggingapi commands in the AWS Command Line Interface Documentation or resourcegroupstaggingapi in the AWS SDK.

(Deprecated) A string-to-string map of key-value pairs that defines the tags to associate with the campaign. Each tag consists of a required tag key and an associated tag value.

pub fn template_configuration(&self) -> Option<&TemplateConfiguration>

The message template to use for the campaign.

pub fn treatment_description(&self) -> Option<&str>

A custom description of the default treatment for the campaign.

pub fn treatment_name(&self) -> Option<&str>

A custom name of the default treatment for the campaign, if the campaign has multiple treatments. A treatment is a variation of a campaign that's used for A/B testing.

pub fn priority(&self) -> Option<i32>

Defines the priority of the campaign, used to decide the order of messages displayed to user if there are multiple messages scheduled to be displayed at the same moment.

Source

impl WriteCampaignRequest

pub fn builder() -> WriteCampaignRequestBuilder

Creates a new builder-style object to manufacture WriteCampaignRequest.