#[non_exhaustive]pub struct WriteEventStream {
pub destination_stream_arn: Option<String>,
pub role_arn: Option<String>,
}Expand description
Specifies the Amazon Resource Name (ARN) of an event stream to publish events to and the AWS Identity and Access Management (IAM) role to use when publishing those events.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination_stream_arn: Option<String>The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis Data Firehose delivery stream that you want to publish event data to.
For a Kinesis data stream, the ARN format is: arn:aws:kinesis:
For a Kinesis Data Firehose delivery stream, the ARN format is: arn:aws:firehose:
role_arn: Option<String>The AWS Identity and Access Management (IAM) role that authorizes Amazon Pinpoint to publish event data to the stream in your AWS account.
Implementations
Sourceimpl WriteEventStream
impl WriteEventStream
Sourcepub fn destination_stream_arn(&self) -> Option<&str>
pub fn destination_stream_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Amazon Kinesis data stream or Amazon Kinesis Data Firehose delivery stream that you want to publish event data to.
For a Kinesis data stream, the ARN format is: arn:aws:kinesis:
For a Kinesis Data Firehose delivery stream, the ARN format is: arn:aws:firehose:
Sourceimpl WriteEventStream
impl WriteEventStream
Sourcepub fn builder() -> WriteEventStreamBuilder
pub fn builder() -> WriteEventStreamBuilder
Creates a new builder-style object to manufacture WriteEventStream.