#[non_exhaustive]pub struct MultiConditionalSplitActivityBuilder { /* private fields */ }Expand description
A builder for MultiConditionalSplitActivity.
Implementations
Sourceimpl MultiConditionalSplitActivityBuilder
impl MultiConditionalSplitActivityBuilder
Sourcepub fn branches(self, input: MultiConditionalBranch) -> Self
pub fn branches(self, input: MultiConditionalBranch) -> Self
Appends an item to branches.
To override the contents of this collection use set_branches.
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.
Sourcepub fn set_branches(self, input: Option<Vec<MultiConditionalBranch>>) -> Self
pub fn set_branches(self, input: Option<Vec<MultiConditionalBranch>>) -> Self
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.
Sourcepub fn get_branches(&self) -> &Option<Vec<MultiConditionalBranch>>
pub fn get_branches(&self) -> &Option<Vec<MultiConditionalBranch>>
The paths for the activity, including the conditions for entering each path and the activity to perform for each path.
Sourcepub fn default_activity(self, input: impl Into<String>) -> Self
pub fn default_activity(self, input: impl Into<String>) -> Self
The unique identifier for the activity to perform for participants who don't meet any of the conditions specified for other paths in the activity.
Sourcepub fn set_default_activity(self, input: Option<String>) -> Self
pub fn set_default_activity(self, input: Option<String>) -> Self
The unique identifier for the activity to perform for participants who don't meet any of the conditions specified for other paths in the activity.
Sourcepub fn get_default_activity(&self) -> &Option<String>
pub fn get_default_activity(&self) -> &Option<String>
The unique identifier for the activity to perform for participants who don't meet any of the conditions specified for other paths in the activity.
Sourcepub fn evaluation_wait_time(self, input: WaitTime) -> Self
pub fn evaluation_wait_time(self, input: WaitTime) -> Self
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.
Sourcepub fn set_evaluation_wait_time(self, input: Option<WaitTime>) -> Self
pub fn set_evaluation_wait_time(self, input: Option<WaitTime>) -> Self
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.
Sourcepub fn get_evaluation_wait_time(&self) -> &Option<WaitTime>
pub fn get_evaluation_wait_time(&self) -> &Option<WaitTime>
The amount of time to wait or the date and time when Amazon Pinpoint determines whether the conditions are met.
Sourcepub fn build(self) -> MultiConditionalSplitActivity
pub fn build(self) -> MultiConditionalSplitActivity
Consumes the builder and constructs a MultiConditionalSplitActivity.