#[non_exhaustive]pub struct ConditionalSplitActivity {
pub condition: Option<Condition>,
pub evaluation_wait_time: Option<WaitTime>,
pub false_activity: Option<String>,
pub true_activity: Option<String>,
}Expand description
Specifies the settings for a yes/no split activity in a journey. This type of activity sends participants down one of two paths in a journey, based on conditions that you specify.
To create yes/no split activities that send participants down different paths based on push notification events (such as Open or Received events), your mobile app has to specify the User ID and Endpoint ID values. For more information, see Integrating Amazon Pinpoint with your application in the Amazon Pinpoint Developer Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.condition: Option<Condition>The conditions that define the paths for the activity, and the relationship between the conditions.
evaluation_wait_time: Option<WaitTime>The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.
false_activity: Option<String>The unique identifier for the activity to perform if the conditions aren't met.
true_activity: Option<String>The unique identifier for the activity to perform if the conditions are met.
Implementations
Sourceimpl ConditionalSplitActivity
impl ConditionalSplitActivity
Sourcepub fn condition(&self) -> Option<&Condition>
pub fn condition(&self) -> Option<&Condition>
The conditions that define the paths for the activity, and the relationship between the conditions.
Sourcepub fn evaluation_wait_time(&self) -> Option<&WaitTime>
pub fn evaluation_wait_time(&self) -> Option<&WaitTime>
The amount of time to wait before determining whether the conditions are met, or the date and time when Amazon Pinpoint determines whether the conditions are met.
Sourcepub fn false_activity(&self) -> Option<&str>
pub fn false_activity(&self) -> Option<&str>
The unique identifier for the activity to perform if the conditions aren't met.
Sourcepub fn true_activity(&self) -> Option<&str>
pub fn true_activity(&self) -> Option<&str>
The unique identifier for the activity to perform if the conditions are met.
Sourceimpl ConditionalSplitActivity
impl ConditionalSplitActivity
Sourcepub fn builder() -> ConditionalSplitActivityBuilder
pub fn builder() -> ConditionalSplitActivityBuilder
Creates a new builder-style object to manufacture ConditionalSplitActivity.